Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildup 1
%define buildsmp 1
%define buildsource 0
%define builddoc 0

# add provides that include the target architecture

%define archprovides 1

# define the redhat release we are compiling on
%define distro  %(awk '/Fedora/{print $4};/Red Hat/{print $5}' 2>/dev/null </etc/redhat-release)

# are we building the planet ccrma kernel?
%define buildplanet 1

# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%define sublevel 12
%define kversion 2.6.%{sublevel}
%define rpmversion 2.6.%{sublevel}
%define rhbsys  .rdt
%define release %(R="$Revision: 0.3$"; RR="${R##: }"; echo ${RR%%?})%{rhbsys}
%define signmodules 0
%define make_target bzImage

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

# groups of related archs
%define all_x86 i586 i686

# Override generic defaults with per-arch defaults 

%ifarch noarch
%define builddoc 1
%define buildsource 1
%define buildup 0
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}*.config
%endif

%if "%{distro}" == "1"
%define gccversion CC=gcc32
%else
%define gccversion %{nil}
%endif

# Second, per-architecture exclusions (ifarch)

%ifarch %{all_x86}
%if "%{buildplanet}" == "1"
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.ccrma.config
%define signmodules 0
%else
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config
%define signmodules 1
%endif
%define image_install_path boot
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%define image_install_path boot
%define signmodules 1
%endif

%ifarch ppc64
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define signmodules 1
%define make_target bzImage zImage.stub
%endif

%ifarch ppc64iseries
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define signmodules 1
%define make_target bzImage
%endif

%ifarch s390
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390*.config
%define image_install_path boot
%endif

%ifarch s390x
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390x.config
%define image_install_path boot
%endif

%ifarch sparc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc.config
%define buildsmp 0
%endif

%ifarch sparc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc64*.config
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc*.config
%define buildsmp 0
%define image_install_path boot
%endif

%ifarch ia64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ia64.config
%define buildsmp 0
%define image_install_path boot/efi/EFI/redhat
%define signmodules 1
%endif


#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 1.0.3, e2fsprogs < 1.29, util-linux < 2.10, jfsutils < 1.0.14, reiserfsprogs < 3.6.3, xfsprogs < 2.1.0, procps < 2.0.9, oprofile < 0.5.3

# 
# Then a series of requirements that are distribution specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, initscripts < 7.23, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, modutils, initscripts >= 5.83, mkinitrd >= 3.5.5

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}%{?disttag:.%{disttag}}
ExclusiveArch: noarch %{all_x86} x86_64 ppc64 ppc64iseries sparc sparc64 ppc s390 s390x ia64
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
%if "%{archprovides}" == "1"
Provides: kernel-%{version}-%{release}-%{_target_cpu}
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

#
# List the packages used during the kernel build
#
BuildPreReq: modutils, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, gnupg
%{?fc3:BuildRequires: kernel-utils}
%{?fc2:BuildRequires: kernel-utils}
BuildRequires: gcc >= 2.96-98, binutils >= 2.12, redhat-rpm-config
BuildConflicts: rhbuildsys(DiskFree) < 500Mb



Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2

Source10: COPYING.modules
Source11: genkey

Source20: kernel-%{kversion}-i586.config
Source21: kernel-%{kversion}-i586-smp.config
Source22: kernel-%{kversion}-i686.config
Source23: kernel-%{kversion}-i686-smp.config
Source25: kernel-%{kversion}-x86_64.config
Source26: kernel-%{kversion}-x86_64-smp.config
Source27: kernel-%{kversion}-ppc64.config
Source28: kernel-%{kversion}-ppc64iseries.config
Source29: kernel-%{kversion}-s390.config
Source30: kernel-%{kversion}-s390x.config
#Source31: kernel-%{kversion}-sparc.config
#Source32: kernel-%{kversion}-sparc64.config
#Source33: kernel-%{kversion}-sparc64-smp.config
Source34: kernel-%{kversion}-ppc.config
Source35: kernel-%{kversion}-ia64.config

Source40: kernel-%{kversion}-i586.ccrma.config
Source41: kernel-%{kversion}-i586-smp.ccrma.config
Source42: kernel-%{kversion}-i686.ccrma.config
Source43: kernel-%{kversion}-i686-smp.ccrma.config

Source50: kernel-update-configs

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
Patch3: patch-2.6.9-ac10.bz2

#
# Patches 10 to 100 are upstream patches we want to back out 
#
Patch10: linux-2.6.9-ac-backouts.patch
Patch11: linux-2.6.7-iobitmap.patch
Patch12: linux-2.6.9-megaraid-backout.patch

# Patches 100 through 500 are meant for architecture patches

# 200 - 300   x86(-64)
Patch200: linux-2.6.5-x86-nostack.patch
Patch201: linux-2.6.9-x86_64-copy_user_generic-exception.patch

# 300 - 330   ppc(64)
Patch300: linux-2.6.2-ppc64-build.patch
Patch301: linux-2.6.8-ppc64-netboot.patch
Patch302: linux-2.6.9-ppc64-singlestep.patch
Patch303: linux-2.6.9-ppc64-hvsi-udbg.patch
Patch304: linux-2.6.9-ppc64-hvsi-reset.patch
Patch305: linux-2.6.9-ppc64-pci-hostbridge-hotplug.patch
Patch306: linux-2.6.9-ppc64-vscsi.patch
Patch307: linux-2.6.9-ppc64-signal-backtrace.patch
Patch308: linux-2.6.9-ppc64-hvsi-hangup.patch

# 330 - 350   ia64
Patch330: linux-2.6.3-ia64-build.patch
Patch340: linux-2.6.9-ia64-sn2-update.patch
Patch341: linux-2.6.9-ia64-pci-sn2-fix.patch
Patch342: linux-2.6.9-ia64-mmtimer-sn2-fix.patch
Patch343: linux-2.6.9-ia64-qla1280-sn2-fix.patch
Patch344: linux-2.6.9-ia64-sgiioc4-sn2-fix.patch
Patch345: linux-2.6.9-ia64-sn-console-sn2-fix.patch
Patch346: linux-2.6.9-ia64-snsc-sn2-fix.patch
Patch347: linux-2.6.9-ia64-cyclone-timer-fix.patch

# 350 - 400   s390(x)
Patch350: linux-2.6.1-s390-compile.patch
Patch351: linux-2.6.9-s390-autoraid.patch
Patch352: linux-2.6.9-s390-qeth-fake_ll-fix.patch
Patch354: linux-2.6.9-s390-zfcp-stackframe.patch
Patch355: linux-2.6.9-s390-dasd-param-parse.patch
Patch356: linux-2.6.9-s390-dasd-fixed-buffer.patch
Patch357: linux-2.6.9-s390-core_dump-fix.patch
Patch358: linux-2.6.9-s390-lcs_startup-fix.patch
Patch359: linux-2.6.9-s390-qeth_addr-fix.patch
Patch360: linux-2.6.9-s390-qeth_hipersocket-fix.patch
Patch361: linux-2.6.9-s390-zfcp_port-fix.patch

# 400 - sparc(64)
Patch400: linux-2.6.3-sparc-addbzimage.patch

#
# Patches 500 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch500: linux-2.4.0-nonintconfig.patch
Patch501: linux-2.6.10-nonintconfig.patch
Patch502: linux-2.6.11-nonintconfig.patch
Patch510: linux-2.6.8-flexmmap-x86-64.patch
Patch511: linux-2.6.0-exec-shield.patch
Patch512: linux-2.6.8-print-fatal-signals.patch
Patch513: linux-2.6.8-execshield-vaspace.patch
Patch520: linux-2.6.8-4g4g-backout.patch
Patch521: linux-2.6.0-4g4g.patch
Patch522: linux-2.6.9-4g4g-noncachable.patch
Patch530: linux-2.6.0-must_check.patch
Patch540: linux-2.6.2-tux.patch
# Module signing infrastructure.
Patch600: linux-2.6.7-modsign-core.patch
Patch601: linux-2.6.10-mm1-modsign-crypto.patch
Patch602: linux-2.6.7-modsign-ksign.patch
Patch603: linux-2.6.7-modsign-mpilib.patch
Patch604: linux-2.6.7-modsign-script.patch
Patch605: linux-2.6.7-modsign-include.patch
Patch606: linux-2.6.12rc2-sha1.patch


#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#
Patch1000: linux-2.4.0-test11-vidfail.patch
Patch1020: linux-2.6.4-stackusage.patch
Patch1030: linux-2.6.5-ext3-reservations.patch
Patch1031: linux-2.6.8-ext3-reservations-update.patch
Patch1040: linux-2.6.5-ext3-online-resize.patch
Patch1050: linux-2.6.7-devmem.patch
Patch1051: linux-2.6.0-devmem.patch
Patch1060: linux-2.6.3-crash-driver.patch
Patch1070: linux-2.6.0-sleepon.patch
Patch1080: linux-2.6.7-voluntary-preemption.patch
Patch1081: linux-2.6.7-early-schedule.patch

# SCSI bits.
Patch1120: linux-2.6.7-scsi-whitelist.patch
Patch1121: linux-2.6.9-scsi-bounce-limit.patch
Patch1122: linux-2.6.9-aic-hostraid.patch

Patch1140: linux-2.6.9-blockfixes.patch

Patch1150: linux-2.6.9-sata.patch
Patch1151: linux-2.6.9-sata-nth-page.patch
Patch1152: linux-2.6.9-sata-ahci-update.patch
Patch1153: linux-2.6.9-sata-updates.patch

Patch1160: linux-2.6.9-kexec.patch
Patch1170: linux-2.6.9-vm-tame-oomkiller.patch
Patch1190: linux-2.6.9-nonpower2sectorsize.patch
Patch1200: linux-2.6.9-module_version.patch
Patch1210: linux-2.6.9-SIOCGIFHWADDR-NULL-dev_addr.patch

# NFS bits.
Patch1220: linux-2.6.9-NFS-mounthangfix.patch
Patch1221: linux-2.6.9-NFSD-non-null-getxattr.patch
Patch1222: linux-2.6.9-NFSD-locallock-oopsfix.patch
Patch1223: linux-2.6.9-NFSD-putrootfh-return.patch
Patch1224: linux-2.6.9-NFSD-portwarning-dottedquads.patch
Patch1225: linux-2.6.9-NFS-cthon-rename.patch
Patch1227: linux-2.6.8-lockd-racewarn2.patch
Patch1228: linux-2.6.9-lockd-NLM-length.patch

Patch1230: linux-2.6.9-irqaffinity-disable-E7xxx.patch
Patch1260: linux-2.6.9-ASPM-workaround-PCIE.patch
Patch1261: linux-2.6.9-hotplug-msi-update.patch
Patch1262: linux-2.6.9-80332-IOP-hotplug.patch
Patch1263: linux-2.6.9-ExpressCard-hotplug-ICH6M.patch
Patch1264: linux-2.6.9-pcix-hotplug-fixes.patch
Patch1270: linux-2.6.9-hugetlb_get_unmapped_area-fix.patch 
Patch1280: linux-2.6.9-ipv6-fix-mtu-calculation.patch
Patch1290: linux-2.6.9-idefloppy-suppress-noise.patch
Patch1300: linux-2.6.9-tg3-fiber-autoneg-bounces.patch
Patch1310: linux-2.6.9-pci_mmcfg_write-flush_error.patch
Patch1320: linux-2.6.9-via-apic-quirk-devinit.patch
 
# ACPI Horrors.
Patch1400: linux-2.6.9-acpi-breakpoint-nop.patch
 
# Netdump bits.
Patch1500: linux-2.6.8-crashdump-common.patch
Patch1510: linux-2.6.7-netdump.patch
Patch1520: linux-2.6.8-netconsole.patch
Patch1530: linux-2.6.9-netpoll-oops.patch

# Diskdump goodies.
Patch1540: linux-2.6.8-diskdump-3.patch
Patch1541: linux-2.6.8-diskdump-scsi-3.patch
Patch1542: linux-2.6.8-mptfusion-diskdump.patch
Patch1543: linux-2.6.7-aic7xxx-diskdump.patch
Patch1544: linux-2.6.8-sym53c8xx-diskdump.patch
Patch1545: linux-2.6.8-ipr-diskdump.patch
Patch1546: linux-2.6.9-diskdump-dienmi.patch
Patch1547: linux-2.6.9-diskdump-export_state.patch
Patch1548: linux-2.6.9-diskdump-mdelay.patch
Patch1549: linux-2.6.9-diskdump-mem.patch
Patch1550: linux-2.6.9-diskdump-system_state.patch
Patch1551: linux-2.6.9-diskdump-condition.patch

# SELinux bits
Patch1600: linux-2.6.9-selinux-netif-fixes.patch
Patch1601: linux-2.6.9-selinux-setxattr-daccheck.patch
Patch1602: linux-2.6.9-selinux-sidtab-locking-fix.patch
Patch1603: linux-2.6.9-selinux-mediate-send_sigurg.patch
Patch1604: linux-2.6.9-selinux-setscheduler-deadlock.patch
Patch1605: linux-2.6.9-selinux-avc-rcu.patch
Patch1606: linux-2.6.9-xattr-rework-tmpfs-mm.patch

Patch2000: linux-2.6.3-printopen.patch

#
# External drivers that are about to get accepted upstream
#

# Speedtouch USB DSL modem driver.
Patch3010: linux-2.6.9-speedtouch.patch

# Intel Centrino wireless drivers.
Patch3020: linux-2.6.9-ipw2100.patch
Patch3021: linux-2.6.9-ipw2200.patch
Patch3022: linux-2.6.9-ieee80211.patch

#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only these should go here. 
# Not patches you're too lazy for to put in the proper place.
#

Patch10000: linux-2.6.0-compile.patch

#
# 20000+ Planet CCRMA patches
#

# kernel subsublevel patch
Patch19999: kernel-subsublevel.patch

# realtime security kernel module
Patch20000: linux-2.6.9-rt-0.1.1.patch.gz
Patch20001: linux-2.6.10-rc2-mm3-rt2.patch.gz

# 2.6.8.1 main Makefile patch
Patch20002: linux-2.6.8.1-makefile.patch

# add realtime nice command to sysrq key
Patch20003: linux-2.6.8-sysnice.patch

# turn off warning on unused result for redhat 9
Patch20010: linux-2.6.0-warn_unused_result.patch

# Ingo Molnar voluntary preemption patch
# http://people.redhat.com/mingo/realtime-preempt/

# prerequisites
# Patch20300: patch-2.6.12-rc2-nonameconnect.bz2
Patch20300: patch-2.6.12-rc5-nonameconnect.bz2
Patch20310: 2.6.10-mm1.bz2
Patch20330: realtime-preempt-2.6.12-final-V0.7.50-06

# gpl symbol exports for nvidia kernel modules
Patch20510: linux-2.6.10-rc3-mm1-gplexports.patch

# compilation fix for rc5
Patch20515: linux-2.6.12-rc5-ipmi.patch

# fix for redefinition of symbol in rc6
Patch20520: linux-2.6.12-rc6-ieee80211.patch

# END OF PATCH DEFINITIONS

Vendor: Planet CCRMA
Distribution: Planet CCRMA
BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.


%package sourcecode
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: make >= 3.78
Requires: gcc >= 3.2
Requires: /usr/bin/strip
# for xconfig and gconfig
Requires: qt-devel, gtk2-devel readline-devel ncurses-devel
Provides: kernel-source
Obsoletes: kernel-source <= 2.6.6

%description sourcecode
The kernel-sourcecode package contains the source code files for the Linux
kernel. The source files can be used to build a custom kernel that is
smaller by virtue of only including drivers for your particular hardware, if
you are so inclined (and you know what you're doing). The customisation
guide in the documentation describes in detail how to do this. This package
is neither needed nor usable for building external kernel modules for
linking such modules into the default operating system kernels.

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation
%if !%{buildsource}
Obsoletes: kernel-source <= 2.6.6
Obsoletes: kernel-sourcecode <= 2.6.6
%endif

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package smp
Summary: The Linux kernel compiled for SMP machines.

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
%if "%{archprovides}" == "1"
Provides: kernel-%{version}-%{release}smp-%{_target_cpu}
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{kversion}

# Planet CCRMA patches
%if "%{buildplanet}" == "1"

# fix subsublevel in version code macro
%patch19999 -p1

# latest stable
# %patch20300 -p1

# latest mm
# %patch20310 -p1

# voluntary preemption
%patch20330 -p0

# realtime security kernel module
# replaced by rlimits in 2.6.12-rc4
# %patch20001 -p1

# gpl export fix for nvidia drivers
# %patch20510 -p1

# compilation fix in rc5
# %patch20515 -p1

# sysnice key
# no longer patches cleanly (S2)
# %patch20003 -p1

# nonint_oldconfig target
%patch502 -p1

# GPG signed kernel modules
%patch600 -p1
%patch601 -p1
%patch602 -p1
%patch603 -p1
%patch604 -p1
%patch605 -p1
%patch606 -p1

# Intel wireless
%patch3020 -p1
%patch3021 -p1
%patch3022 -p1

# fix for redefinition of symbol in intel wireless
%patch20520 -p1

%endif

# Disable all original Fedora patches
%if "%{buildplanet}" != "1"

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

# Various fixes from Alan's -ac tree.
%patch3 -p1

#
# Patches to back out
#

# -AC bits we don't want.
%patch10 -p1 -R
# iobitmap increase that breaks booting
%patch11 -p1 -R
# Drop 2.6.9 megaraid breakage
%patch12 -p1 -R

#
# Architecture patches
#

#
# x86(-64)
#
%patch200 -p1
# fix x86_64 copy_user_generic
%patch201 -p1


# 
# ppc64
#

# Patch for Kconfig and Makefile build issues
%patch300 -p1
%patch301 -p1
# Fix single stepping on PPC64
%patch302 -p1
# HVSI udbg support
%patch303 -p1
# Make HVSI console survive FSP reset
%patch304 -p1
# Make PCI hostbridge hotplugging work
%patch305 -p1
# Fix IBM VSCSI problems
%patch306 -p1
# Store correct backtracking info in ppc64 signal frames
%patch307 -p1
# Prevent HVSI from oopsing on hangup
%patch308 -p1

#
# ia64
#

# Basic build fixes
%patch330 -p1
%patch340 -p1
%patch341 -p1
%patch342 -p1
%patch343 -p1
%patch344 -p1
%patch345 -p1
%patch346 -p1
%patch347 -p1


#
# s390
#

# Basic build fixes
%patch350 -p1
# Auto raidstart for S390
%patch351 -p1
# Fix fake_ll for QETH device  (#136175)
%patch352 -p1
# zfcp: Kernel stack frame for zfcp_cfdc_dev_ioctl() is too big
%patch354 -p1
# Fixed buffers for DASD devices.
%patch355 -p1
%patch356 -p1
# Fix coredumps on S390
%patch357 -p1
# lcs device will not start anymore after first detection.
%patch358 -p1
# Fix possible failure of IP addr registration
%patch359 -p1
# Support broadcast on z800/z900 HiperSockets
%patch360 -p1
# Recover after aborted nameserver request.
%patch361 -p1

#
# sparc/sparc64
#
%patch400 -p1
#
# Patches 500 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
%patch500 -p1


#
# The execshield patch series, broken into smaller pieces
#
# 1) Flexible mmap patch 
#
%patch510 -p1

# 2) Exec shield core
#
%patch511 -p1

# 3) Option to printk fatal signals, useful for debugging
#
%patch512 -p1

# 4) The Execshield VA rearrangements
#
%patch513 -p1

#
# 4G/4G split
#
%patch520 -p1 -R
%patch521 -p1
%patch522 -p1

#
# Patch that adds a __must_check attribute for functions for which checking
# the return value is mantadory (eg copy_from_user)
#
%patch530 -p1

#
# TUX
#
%patch540 -p1

#
# GPG signed kernel modules
#
%patch600 -p1
%patch601 -p1
%patch602 -p1
%patch603 -p1
%patch604 -p1
%patch605 -p1
%patch606 -p1


#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#


# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer cd that wants to automatically fall back to textmode
# in that case
%patch1000 -p1

#
# Fix the extreme stack usage in some kernel functions
#
%patch1020 -p1


#
# Ext3 reservations. reduces fragmentation bigtime
#
%patch1030 -p1
%patch1031 -p1

#
# ext3 online resize
#
%patch1040 -p1

#
# Make /dev/mem a need-to-know function 
#
%patch1050 -p1
%patch1051 -p1


#
# /dev/crash driver for the crashdump analysis tool
#
%patch1060 -p1

#
# Most^WAll users of sleep_on are broken; fix a bunch
#
%patch1070 -p1

#
# Ingo's patch for voluntary preemption
#
%patch1080 -p1
%patch1081 -p1

#
# SCSI Bits.
#
# Additions to the SCSI whitelist to make card readers work.
%patch1120 -p1
# fix SCSI bounce limit
%patch1121 -p1
# AIC host raid support.
%patch1122 -p1


#
# Fix blocklayer races
#
%patch1140 -p1

#
# Sata update
# 
%patch1150 -p1
%patch1151 -p1
%patch1152 -p1
%patch1153 -p1

# Kexec in preparation for kexec-based dump
%patch1160 -p1

# Forcefully deactivate a few pages when we run with
# priority 0 to prevent false OOM kills.
%patch1170 -p1

#
# Fix problems with non-power-of-two sector size discs
#
%patch1190 -p1

#
# Add missing MODULE_VERSION tags to some modules.
#
%patch1200 -p1

#
# Handle SIOCGIFHWADDR NULL dev->dev_addr
#
%patch1210 -p1

#
# Various upstream NFS/NFSD fixes.
#
%patch1220 -p1
%patch1221 -p1
%patch1222 -p1
%patch1223 -p1
%patch1224 -p1
%patch1225 -p1
%patch1227 -p1
%patch1228 -p1

#
# Random fixes.
#
# disable sw irqbalance/irqaffinity for e7520-e7320-e7525
%patch1230 -p1
# ASPM workaround for PCIe
%patch1260 -p1
# Hot-plug driver updates due to MSI change
%patch1261 -p1
# Workaround for 80332 IOP hot-plug problem
%patch1262 -p1
# ExpressCard hot-plug support for ICH6M
%patch1263 -p1
# Various PCI-X hotplug fixes
%patch1264 -p1
# hugetlb_get_unmapped_area fix
%patch1270 -p1
# Fix IPV6 MTU calculation
%patch1280 -p1
# Suppress ide-floppy 'medium not present' noise
%patch1290 -p1
# [TG3]: Fix fiber hw autoneg bounces
%patch1300 -p1
# flush error in pci_mmcfg_write
%patch1310 -p1
# Fix boot crash on VIA systems
%patch1320 -p1

# ACPI bits
# Eliminate spurious ACPI breakpoint msgs
%patch1400 -p1

#
# Various crash dumping patches
#
%patch1500 -p1
%patch1510 -p1
%patch1520 -p1
%patch1530 -p1
%patch1540 -p1
%patch1541 -p1
%patch1542 -p1
%patch1543 -p1
%patch1544 -p1
%patch1545 -p1
%patch1546 -p1
%patch1547 -p1
%patch1548 -p1
%patch1549 -p1
%patch1550 -p1
%patch1551 -p1

#
# Various SELinux fixes from 2.6.10rc
#
%patch1600 -p1
%patch1601 -p1
%patch1602 -p1
%patch1603 -p1
%patch1604 -p1
%patch1605 -p1
# SELinux xattr for tmpfs (from 2.6.9-mm)
%patch1606 -p1

#
# Local hack (off for any shipped kernels) to printk all files opened 
# the first 180 seconds after boot for debugging userspace startup 
# speeds
#
# %patch2000 -p1

#
# External drivers that are about to get accepted upstream
#

# Speedtouch
%patch3010 -p1

# Intel wireless
%patch3020 -p1
%patch3021 -p1
%patch3022 -p1

#
# Patches 5000 to 6000 are reserved for new drivers that are about to
# be merged upstream
#


#
# final stuff
#

#
# misc small stuff to make things compile or otherwise improve performance
#
%patch10000 -p1

# End of disable all original Fedora patches
%endif

# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -fv %{all_arch_configs} .

# change options for testing
for i in *.config ; do
# temporarily disable, undefined symbols (01/19/2004)
	perl -p -i -e "s|CONFIG_NET_ACT_IPT=m|# CONFIG_NET_ACT_IPT is not set|g" $i
# CONFIG_DEBUG_SPINLOCK=y
# CONFIG_DEBUG_SPINLOCK_SLEEP=y
#	perl -p -i -e "s|CONFIG_DEBUG_SPINLOCK=y|# CONFIG_DEBUG_SPINLOCK is not set|g" $i
#	perl -p -i -e "s|CONFIG_DEBUG_SPINLOCK_SLEEP=y|# CONFIG_DEBUG_SPINLOCK_SLEEP is not set|g" $i
#	perl -p -i -e "s|CONFIG_PREEMPT_VOLUNTARY=y|# CONFIG_PREEMPT_VOLUNTARY is not set|g" $i
#	perl -p -i -e "s|CONFIG_PREEMPT_RT=y|# CONFIG_PREEMPT_RT is not set|g" $i
#	perl -p -i -e "s|# CONFIG_PREEMPT_DESKTOP is not set|CONFIG_PREEMPT_DESKTOP=y|g" $i
done

# now run oldconfig over all the config files
for i in *.config 
do 
	mv $i .config 
	make ARCH=`echo $i | cut -d"-" -f3 | cut -d"." -f1 | sed -e s/i.86/i386/ -e s/s390x/s390/ -e s/ppc64.series/ppc64/  ` nonint_oldconfig > /dev/null 
	cp .config configs/$i 
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

###
### build
###
%build

#
# Create gpg keys for signing the modules
#

gpg --homedir /tmp --batch --gen-key %{SOURCE11} 
gpg --homedir /tmp --export --keyring ./kernel.pub Red > extract.pub
make linux-%{kversion}/scripts/bin2c
linux-%{kversion}/scripts/bin2c ksign_def_public_key __initdata < extract.pub > linux-%{kversion}/crypto/signature/key.h

cd linux-%{kversion}



BuildKernel() {

    # Pick the right config file for the kernel we're building
    if [ -n "$1" ] ; then
%if "%{buildplanet}" == "1"
	Config=kernel-%{kversion}-%{_target_cpu}-$1.ccrma.config
%else
	Config=kernel-%{kversion}-%{_target_cpu}-$1.config
%endif
    else
%if "%{buildplanet}" == "1"
	Config=kernel-%{kversion}-%{_target_cpu}.ccrma.config
%else
	Config=kernel-%{kversion}-%{_target_cpu}.config
%endif
    fi

    KernelVer=%{version}-%{release}$1
    echo BUILDING A KERNEL FOR $1 %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$1/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    make -s nonint_oldconfig > /dev/null
    make -s include/linux/version.h 

    # temporary hack: make sure we have comakehash
    gcc -o scripts/conmakehash scripts/conmakehash.c

    make -s %{?_smp_mflags} %{gccversion} %{make_target}
    make -s %{?_smp_mflags} %{gccversion} modules || exit 1
    make %{gccversion} buildcheck
    
    # Start installing the results

    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    cp arch/*/boot/bzImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    cp arch/*/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s %{gccversion} INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
 
    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files 

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # first copy everything
    cp --parents `find  -type f -name Makefile -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build 
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config linux math-emu media net pcmcia rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    cd .. 

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer

    # gpg sign the modules
%if %{signmodules}
    gcc -o scripts/modsign/mod-extract scripts/modsign/mod-extract.c -Wall
    for i in ` find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f` ; do
	sh ./scripts/modsign/modsign.sh $i Red
        mv -f $i.signed $i
    done
%endif

    # mark modules executable so that strip-to-file can strip them
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f  | xargs chmod u+x

    # detect missing or incorrect license tags
    for i in `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" ` ; do echo -n "$i " ; /sbin/modinfo -l $i >> modinfo ; done
    cat modinfo | grep -v "^GPL" | grep -v "^Dual BSD/GPL" | grep -v "^Dual MPL/GPL" | grep -v "^GPL and additional rights" | grep -v "^GPL v2" && exit 1 
    rm -f modinfo
    # remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{buildup}
BuildKernel
%endif

%if %{buildsmp}
BuildKernel smp
%endif

###
### install
###

%install

cd linux-%{kversion}

# architectures that don't get kernel-source (i586/i686/athlon) dont need
# much of an install because the build phase already copied the needed files

%if %{builddoc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}
%endif

%if %{buildsource}

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
chmod -R a+r *

# clean up the source tree so that it is ready for users to build their own
# kernel
make -s mrproper
# copy the source over
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# set the EXTRAVERSION to <version>custom, so that people who follow a kernel building howto
# don't accidentally overwrite their currently working moduleset and hose
# their system
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile

# some config options may be appropriate for an rpm kernel build but are less so for custom user builds,
# change those to values that are more appropriate as default for people who build their own kernel.
perl -p -i -e "s/^CONFIG_DEBUG_INFO.*/# CONFIG_DEBUG_INFO is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_PAGEALLOC.*/# CONFIG_DEBUG_PAGEALLOC is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_SLAB.*/# CONFIG_DEBUG_SLAB is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_SPINLOCK.*/# CONFIG_DEBUG_SPINLOCK is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_HIGHMEM.*/# CONFIG_DEBUG_HIGHMEM is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_MODULE_SIG.*/# CONFIG_MODULE_SIG is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*

install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# load the loop module for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
if [ -x /usr/sbin/hardlink ] ; then
pushd /lib/modules/%{KVERREL}/build > /dev/null ; {
	cd /lib/modules/%{KVERREL}/build
	find . -type f | while read f; do hardlink -c /lib/modules/*/build/$f $f ; done
}
popd > /dev/null
fi

%post smp
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
if [ -x /usr/sbin/hardlink ] ; then
pushd /lib/modules/%{KVERREL}smp/build > /dev/null ; {
	cd /lib/modules/%{KVERREL}smp/build
	find . -type f | while read f; do hardlink -c /lib/modules/*/build/$f $f ; done
}
popd > /dev/null
fi


%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp


###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/%{image_install_path}/*-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
%verify(not mtime) /lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source
%endif

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/%{image_install_path}/*-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
%verify(not mtime) /lib/modules/%{KVERREL}smp/build
/lib/modules/%{KVERREL}smp/source
%endif

# only some architecture builds need kernel-source and kernel-doc

%if %{buildsource}
%files sourcecode
%defattr(-,root,root)
/usr/src/linux-%{KVERREL}/
%endif


%if %{builddoc}
%files doc
%defattr(-,root,root)
/usr/share/doc/kernel-doc-%{kversion}/Documentation/*
%endif

%changelog
* Tue Jun 21 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.12-0.3.rdt
- updated to realtime-preempt-2.6.12-final-V0.7.50-06

* Mon Jun 20 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.12-0.2.rdt
- updated to realtime-preempt-2.6.12-final-V0.7.50-04, the previous one is
  hanging when an irq in my laptop is set to threaded=0

* Sun Jun 19 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.12-0.1.rdt
- 2.6.12 final, realtime-preempt-2.6.12-final-V0.7.49-01
- disabled CONFIG_LPPTEST (set to "n"), scripts/lpptest.c fails to build
  with "concat" found as undefined symbol
- disabled CONFIG_DEBUG_PREEMPT (warning on boot about increased overhead and
  latency)

* Sat Jun 18 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.16.rdt
- back to 0.16.rdt, 0.17.rdt hangs in my test laptop

* Sat Jun 18 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.12-0.1.rdt
- updated to final 2.6.12
- updated to realtime-preempt-2.6.12-rc6-V0.7.48-37
- realtime preempt patch does not apply

* Fri Jun 17 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- add hack to build scripts/conmakehash
- patch for redefinition of symbol in 2.6.12-rc6

* Wed Jun 15 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.17.rdt
- updated to 2.6.12-rc6 and realtime-preempt-2.6.12-rc6-V0.7.48-33 
- new options:
  'conservative' cpufreq governor (CPU_FREQ_GOV_CONSERVATIVE) [N/m/y/?] (NEW) m
  Broadcom NetXtremeII support (BNX2) [N/m/y/?] (NEW) m
Parallel Port Based Latency Measurement Device (LPPTEST) [M/n/?] (NEW) m
    CF/PCMCIA support for SL811HS HCD (USB_SL811_CS) [N/m/?] (NEW) m
    USB Option PCMCIA serial driver (USB_SERIAL_OPTION) [N/m/?] (NEW) m
  Detect Soft Lockups (DETECT_SOFTLOCKUP) [Y/n/?] (NEW) y

* Sun Jun  5 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.16.rdt
- updated to realtime-preempt-2.6.12-rc5-V0.7.47-17

* Wed Jun  1 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.15.rdt
- updated to realtime-preempt-2.6.12-rc5-V0.7.47-16

* Mon May 30 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- updated to realtime-preempt-2.6.12-rc5-V0.7.47-15 (does not build
  with PREEMPT_DESKTOP)

* Fri May 27 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.14.rdt
- updated to realtime-preempt-2.6.12-rc5-V0.7.47-12

* Thu May 26 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.13.rdt
- updated to 2.6.12-rc5 with no NAME_CONNECT and realtime-preempt-2.6.12-rc5-V0.7.47-09
- new options:
    Technisat/B2C2 FlexCopII(b) and FlexCopIII adapters (DVB_B2C2_FLEXCOP) [N/m/?] (NEW) m
      Technisat/B2C2 Air/Sky/Cable2PC PCI (DVB_B2C2_FLEXCOP_PCI) [N/m/?] (NEW) m
      Technisat/B2C2 Air/Sky/Cable2PC USB (DVB_B2C2_FLEXCOP_USB) [N/m/?] (NEW) m
      Enable debug for the B2C2 FlexCop drivers (DVB_B2C2_FLEXCOP_DEBUG) [N/y/?] (NEW) n
- patch to fix compilation (patch20520)

* Wed May 18 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.12.rdt
- updated to realtime-preempt-2.6.12-rc4-V0.7.47-08

* Wed May 18 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.11.rdt
- updated to realtime-preempt-2.6.12-rc4-V0.7.47-03
- do not require kernel-utils in fc4

* Mon May  9 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.10.rdt
- updated to 2.6.12-rc4 (without the NAME_CONNECT chunks)
- updated to realtime-preempt-2.6.12-rc4-V0.7.47-01
- removed realtime lsm module (replaced by the rtlimits stuff in rc4)
  and reverted CONFIG_SECURITY_CAPABILITIES to be "y" instead of "m"
  (which was needed for the realtime lsm)
- configuration options:
> 6. Pentium-Pro (M686)
 Enable X86 board specific fixups for reboot (X86_REBOOTFIXUPS) [N/y/?] (NEW) y
  Simple action (NET_ACT_SIMP) [N/m/y/?] (NEW) m
    USB AirPrime CDMA Wireless Driver (USB_SERIAL_AIRPRIME) [N/m/?] (NEW) m
    USB HP4x Calculators support (USB_SERIAL_HP4X) [N/m/?] (NEW) m

* Tue May  3 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.9.rdt
- updated to realtime-preempt-2.6.12-rc3-V0.7.46-02
- deleted NAME_CONNECT chunks from rc3 patch

* Mon Apr 21 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.8.rdt
- updated to realtime-preempt-2.6.12-rc3-V0.7.46-01

* Mon Apr 11 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.7.rdt
- updated to realtime-preempt-2.6.12-rc2-V0.7.45-01
- removed TCP_SOCKET__NAME_CONNECT policy from 2.6.12-rc2 patch, 
  the default fc3 policy does not know about this and network
  connections fail (patch is patch-2.6.12-rc2-nonameconnect.bz2)
  UPDATE: this seems to solve the web browser problem, there are still
  a couple of errors from portmap and nscd, even with the latest policy
  from fedora. Selinux monitoring of nscd and portmap can be disabled from
  the security control panel.
- restore the default to "1" here (that was not the problem, see above):
    NSA SELinux checkreqprot default value (SECURITY_SELINUX_CHECKREQPROT_VALUE) [1] (NEW) 1

* Thu Apr  7 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.6.rdt
- problems in fc3 with selinux, will try changing this to "0":
    NSA SELinux checkreqprot default value (SECURITY_SELINUX_CHECKREQPROT_VALUE) [1] (NEW) 0

* Wed Apr  6 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.5.rdt
- updated to 2.6.12-rc2 + realtime-preempt-2.6.12-rc2-V0.7.44-01
- options:
Processor family
> 6. Pentium-Pro (M686) 6
Thread RCU (PREEMPT_RCU) [N/y/?] (NEW)
Enable seccomp to safely compute untrusted bytecode (SECCOMP) [Y/n/?] (NEW) y
PCI Debbuging n
    Multipath target (EXPERIMENTAL) (DM_MULTIPATH) [N/m/?] (NEW)
      EMC CX/AX multipath support (EXPERIMENTAL) (DM_MULTIPATH_EMC) [N/m/?] (NEW) m
        IP: equal cost multipath with caching support (EXPERIMENTAL) (IP_ROUTE_MULTIPATH_CACHED) [N/y/?] (NEW) ? n
      Basic classifier (NET_CLS_BASIC) [N/m/y/?] (NEW) m
  Extended Matches (NET_EMATCH) [N/y/?] (NEW) y
    Stack size (NET_EMATCH_STACK) [32] (NEW) 32
    Simple packet data comparison (NET_EMATCH_CMP) [N/m/y/?] (NEW) m
    Multi byte comparison (NET_EMATCH_NBYTE) [N/m/y/?] (NEW) m
    U32 hashing key (NET_EMATCH_U32) [N/m/y/?] (NEW) m
    Metadata (NET_EMATCH_META) [N/m/y/?] (NEW) m
      HFC-4S/8S based ISDN cards (EXPERIMENTAL) (HISAX_HFC4S8S) [N/m/?] (NEW) m
    Twiddler as a joystick (JOYSTICK_TWIDJOY) [N/m/y/?] (NEW) m
    Elo serial touchscreens (TOUCHSCREEN_ELO) [N/m/y/?] (NEW) m
    MicroTouch serial touchscreens (TOUCHSCREEN_MTOUCH) [N/m/y/?] (NEW) m
    ICS MicroClock MK712 touchscreen (TOUCHSCREEN_MK712) [N/m/y/?] (NEW) m
Digi International NEO PCI Support (SERIAL_JSM) [N/m/y/?] (NEW) m
TPM Hardware Support (TCG_TPM) [N/m/y/?] (NEW) m
  National Semiconductor TPM Interface (TCG_NSC) [N/m/?] (NEW) m
  Atmel TPM Interface (TCG_ATMEL) [N/m/?] (NEW) m
  FSC Poseidon (SENSORS_FSCPOS) [N/m/?] (NEW) m
  Genesys Logic GL520SM (SENSORS_GL520SM) [N/m/?] (NEW) m
  National Semiconductor LM92 and compatibles (SENSORS_LM92) [N/m/?] (NEW) m
  Silicon Integrated Systems Corp. SiS5595 (SENSORS_SIS5595) [N/m/?] (NEW) m
  Dallas Semiconductor DS1337 Real Time Clock (SENSORS_DS1337) [N/m/?] (NEW) m
    DVB Support for saa7134 based TV cards (VIDEO_SAA7134_DVB) [N/m/?] (NEW) m
    DVB Support for cx2388x based TV cards (VIDEO_CX88_DVB) [N/m/?] (NEW) m
  nVidia Framebuffer Support (FB_NVIDIA) [N/m/y/?] (NEW) m
    Enable DDC Support (FB_NVIDIA_I2C) [N/y/?] (NEW) y
    Enable DDC2 Support (FB_SAVAGE_I2C) [N/y/?] (NEW) y
    Enable Console Acceleration (FB_SAVAGE_ACCEL) [N/y/?] (NEW) y
  AMD Geode family framebuffer support (EXPERIMENTAL) (FB_GEODE) [N/y/?] (NEW) n
Epson S1D13XXX framebuffer support (FB_S1D13XXX) [N/m/y/?] (NEW) m
  Intel HD Audio (SND_HDA_INTEL) [N/m/?] (NEW) m
    USBAT/USBAT02-based storage support (EXPERIMENTAL) (USB_STORAGE_USBAT) [N/y/?] (NEW) y
  USB Philips Cameras (USB_PWC) [N/m/?] (NEW) m
  USB ZD1201 based Wireless device support (USB_ZD1201) [N/m/y/?] (NEW) m
  USB Monitor (USB_MON) [Y/n/m/?] (NEW) y
    USB CP2101 UART Bridge Controller (USB_SERIAL_CP2101) [N/m/?] (NEW) m
  USB 2.0 SVGA dongle support (Net2280/SiS315) (USB_SISUSBVGA) [N/m/?] (NEW) m
Show timing information on printks (PRINTK_TIME) [N/y/?] (NEW) n
    NSA SELinux checkreqprot default value (SECURITY_SELINUX_CHECKREQPROT_VALUE) [1] (NEW) 1
  Tiger digest algorithms (CRYPTO_TGR192) [N/m/y/?] (NEW) m

* Sat Apr  2 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.4.rdt
- updated to 2.6.11[.6]

* Mon Mar 21 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.3.rdt
- updated to 2.6.11[.5]
- don't add minor release to package name, will only make it difficult to
  transition to rc releases of 2.6.12 (still named 2.6.11 something)

* Sat Mar 18 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.2.rdt
- updated to 2.6.11.4
- updated to realtime-preempt V0.7.40-04

* Fri Mar 11 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.11-0.1.rdt
- updated to 2.6.11.3
- fix sublevel in KERNEL_VERSION_CODE macro (patch19999)

* Fri Mar 11 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- updated to 2.6.11 final

* Thu Feb 24 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-0.7.rdt
- updated to 2.6.11-rc5

* Mon Feb 14 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-0.6.rdt
- updated to 2.6.11-rc4-V0.7.39-02
- new options:
  HCI BPA10x USB driver (BT_HCIBPA10X) [N/m/?] (NEW) m

* Fri Feb  4 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-0.5.rdt
- updated to 2.6.11-rc3-V0.7.38-01
- new options:
    G100/G200/G400/G450/G550 support (FB_MATROX_G) [N/y/?] (NEW) y
      G400 second head support (FB_MATROX_MAVEN) [N/m/?] (NEW) m

* Wed Jan 26 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-0.4.rdt
- updated to 2.6.11-rc2 + 2.6.11-rc2-V0.7.36-05
- added centrino patches from latest fedora kernel (patches 3020-3022)
- new options:
    Generic IEEE 802.11 Networking Stack (IEEE80211) [N/m/y] (NEW) m
      Enable full debugging output (IEEE80211_DEBUG) [N/y/?] (NEW) n
      IEEE 802.11 encryption (IEEE80211_CRYPT) [N/m/?] (NEW) m
        IEEE 802.11 WPA (IEEE80211_WPA) [N/m/?] (NEW) m
          IEEE 802.11 CCMP encryption (IEEE80211_CRYPT_CCMP) [N/m/?] (NEW) m
          IEEE 802.11 TKIP encryption (IEEE80211_CRYPT_TKIP) [N/m/?] (NEW) m
      Intel PRO/Wireless 2100 802.11b (IPW2100) [N/m/?] (NEW) m
        Enable full debugging output (IPW_DEBUG) [N/y/?] (NEW) n
        Enable promiscuous mode (IPW2100_PROMISC) [N/y/?] (NEW) n
        Legacy firmware loading (non-hotplug) (IPW2100_LEGACY_FW_LOAD) [N/y/?] (NEW) n
      Intel PRO/Wireless 2200 802.11bg (IPW2200) [N/m/?] (NEW) m

* Sun Jan 23 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-0.3.rdt
- update to 2.6.11-rc2 + 2.6.11-rc2-V0.7.36-02
- options:
  CPU frequency translation statistics (CPU_FREQ_STAT) [Y/n/m/?] (NEW) m
    CPU frequency translation statistics details (CPU_FREQ_STAT_DETAILS) [N/y/?] (NEW) y
PCI Express support (PCIEPORTBUS) [N/y/?] (NEW) y
  PCI Express Hotplug driver (HOTPLUG_PCI_PCIE) [N/m/y/?] (NEW) m
    Use polling mechanism for hot-plug events (for testing purpose) (HOTPLUG_PCI_PCIE_POLL_EVENT_MODE) [N/y/?] (NEW) n
Backlight & LCD device support (BACKLIGHT_LCD_SUPPORT) [N/y/?] (NEW) y
  Lowlevel Backlight controls (BACKLIGHT_CLASS_DEVICE) [N/m/y/?] (NEW) m
  Lowlevel LCD controls (LCD_CLASS_DEVICE) [N/m/y/?] (NEW) m
Siemens ID USB Mouse Fingerprint sensor support (USB_IDMOUSE) [N/m/y/?] (NEW) m

* Wed Jan 19 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-0.2.rdt
- update to 2.6.11-rc1 + realtime-preempt-2.6.11-rc1-V0.7.35-02
- capability fix patch no longer needed (Patch20500)
- options:
  /proc/cpufreq interface (deprecated) (CPU_FREQ_PROC_INTF) [N/m/y/?] (NEW) n
    /proc/sys/cpu/ interface (2.4. / OLD) (CPU_FREQ_24_API) [N/y/?] (NEW) n
MTD using block device (rewrite) (MTD_BLOCK2MTD) [N/m/?] (NEW) m
ATA over Ethernet support (ATA_OVER_ETH) [M/n/y/?] (NEW) m
          Enable controller even if disabled by BIOS (PDC202XX_FORCE) [N/y/?] (NEW) n
Crystal SoundFusion gameport support (GAMEPORT_CS461X) [N/m] (NEW) m
  SMSC LPC47B397-NC (SENSORS_SMSC47B397) [N/m/?] (NEW) m
Emu10k1X (Dell OEM Version) (SND_EMU10K1X) [N/m/?] (NEW) m
SB Audigy LS / Live 24bit (SND_CA0106) [N/m/?] (NEW) m
VIA 82C686A/B, 8233 based Modems (SND_VIA82XX_MODEM) [N/m/?] (NEW) m
  Garmin GPS driver (USB_SERIAL_GARMIN) [N/m/?] (NEW) m
  USB TI 3410/5052 Serial Driver (USB_SERIAL_TI) [N/m/?] (NEW) m
Debug Filesystem (DEBUG_FS) [N/y/?] (NEW) n

- temporarily disable CONFIG_NET_ACT_IPT=m, there are two undefined
  symbols __ipt_find_target_lock and __ipt_mutex_up, they do not
  seem to be defined anywhere else in the kernel sources.

* Wed Jan  5 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-0.1.rdt
- update the DEKSTOP_PREEMPT kernel to 2.6.10-mm1 + V0.7.34-1
  CPU frequency translation statistics (CPU_FREQ_STAT) [Y/n/m/?] (NEW) m
    CPU frequency translation statistics details (CPU_FREQ_STAT_DETAILS) [N/y/?] (NEW) n
      ebt: ulog support (BRIDGE_EBT_ULOG) [N/m/?] (NEW) m
  Use nfmark as a key in U32 classifier (CLS_U32_MARK) [N/y/?] (NEW) y
  I2C SGI interfaces (I2C_ALGO_SGI) [N/m/?] (NEW) n
MMC support (MMC) [N/m/y/?] (NEW) m
  MMC debugging (MMC_DEBUG) [N/y/?] (NEW) ? n
  MMC block device driver (MMC_BLOCK) [M/n/?] (NEW) m
  Winbond W83L51xD SD/MMC Card Interface support (MMC_WBSD) [N/m/?] (NEW) m
InfiniBand support (INFINIBAND) [N/m/y/?] (NEW) m
  Mellanox HCA support (INFINIBAND_MTHCA) [N/m/?] (NEW) m
    Verbose debugging output (INFINIBAND_MTHCA_DEBUG) [N/y/?] (NEW) n
    SSE doorbell code (INFINIBAND_MTHCA_SSE_DOORBELL) [N/y/?] (NEW) n
  IP-over-InfiniBand (INFINIBAND_IPOIB) [N/m/?] (NEW) m
    IP-over-InfiniBand debugging (INFINIBAND_IPOIB_DEBUG) [N/y/?] (NEW) n
Support for VIA PadLock ACE (CRYPTO_DEV_PADLOCK) [N/m/y/?] (NEW) y
  Support for AES in VIA PadLock (CRYPTO_DEV_PADLOCK_AES) [Y/n/?] (NEW) y

* Wed Dec 29 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.10-2.1.ll
- branch into 2.6.10 final, including the same patches
- comment out the rc, rc-mm and realtime-preempt patches; change
  all .config files to 2.6.10 name
- comment out nvidia gpl symbol export patch
- options:
          Enable controller even if disabled by BIOS (PDC202XX_FORCE) [N/y/?] (NEW) n
      Use PIO instead of MMIO (EEPRO100_PIO) [N/y/?] (NEW) n
MMC support (MMC) [N/m/y/?] (NEW) m
  MMC debugging (MMC_DEBUG) [N/y/?] (NEW) n
  MMC block device driver (MMC_BLOCK) [M/n/?] (NEW) m
  Winbond W83L51xD SD/MMC Card Interface support (MMC_WBSD) [N/m/?] (NEW) m
  QNX4FS write support (DANGEROUS) (QNX4FS_RW) [N/y/?] (NEW) n
  Spinlock debugging (DEBUG_SPINLOCK) [N/y/?] (NEW) y
  Sleep-inside-spinlock checking (DEBUG_SPINLOCK_SLEEP) [N/y/?] (NEW) y
Compile the kernel with frame pointers (FRAME_POINTER) [N/y/?] (NEW) n

* Wed Dec 29 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-2.3.rdt
- added gpl exports patch for nvidia kernel modules (Patch20510), see:
  http://www.nvnews.net/vbulletin/showthread.php?t=42593
- changed over to the simpler capability patch as posted on lkml
  (still Patch20500)

* Mon Dec 26 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-2.2.rdt
- shortened version :-)
- added patch for capability module security bug (Patch20500) as reported in:
  http://www.derkeiler.com/Mailing-Lists/securityfocus/bugtraq/2004-12/0390.html
  (reported by Frank Barknecht on the lad list)

* Wed Dec 23 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-2.1.rdtV0.7.33_04
- added the latest realtime patch to the kernel
  http://www.joq.us/realtime/linux-2.6.10-rc2-mm3-rt2.patch.gz
- removed all realtime preemption tracing and debugging options
- tried to have SECURITY_CAPABILITIES and SECURITY_REALTIME both built
  into the kernel (not as modules). Does not currently work with the 
  realtime kernel module so reverted to both being modules

* Mon Dec 20 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.2.rdtV0.7.33_04
- fixed CONFIG_SPINLOCK_BLK (was using the old BKL method, more latency)
- added realtimedebug configuration variable to turn off most of the tracing
  and debugging options in the realtime kernel patch

* Wed Dec 15 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.33_04
- updated to 0.7.32-04

* Tue Dec 14 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.33_0
- updated to 0.7.32-20 on top of 2.6.10-rc3-mm1, using PREEMPT_DESKTOP
  Location of RedBoot partition table (MTD_REDBOOT_DIRECTORY_BLOCK) [-1] (NEW) -1
XIP aware MTD support (MTD_XIP) [N/y/?] (NEW) ? n
Support for NAND Flash Simulator (MTD_NAND_NANDSIM) [N/y/?] (NEW) ? y
  Default number of RAM disks (BLK_DEV_RAM_COUNT) [16] (NEW) 16
  Analog Devices ADM1026 and compatibles (SENSORS_ADM1026) [N/m/?] (NEW) m
      Enable support for some misdesigned (see help) devices, which identify with wrong IDs (DVB_DIBUSB_MISDESIGNED_DEVICES) [N/y/?] (NEW) y
    B2C2/Technisat Air/Sky/Cable2PC USB (DVB_B2C2_USB) [N/m/?] (NEW) m
SL811HS HCD support (USB_SL811_HCD) [N/m/y/?] (NEW) m
  JFS Security Labels (JFS_SECURITY) [N/y/?] (NEW) y
  CIFS Experimental Features (EXPERIMENTAL) (CIFS_EXPERIMENTAL) [N/y/?] (NEW) n

* Mon Dec 13 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_20
- updated to 0.7.32-20, using PREEMPT_DESKTOP

* Sat Dec 11 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_19
- updated to 0.7.32-19, using PREEMPT_DESKTOP

* Fri Dec 10 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_18
- updated to 0.7.32-18, using PREEMPT_DESKTOP

* Thu Dec  9 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_14
- updated to 0.7.32-14, using PREEMPT_DESKTOP

* Wed Dec  8 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_10
- updated to 0.7.32-10, using PREEMPT_DESKTOP

* Tue Dec  7 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_9
- updated to 0.7.32-9, using PREEMPT_DESKTOP

* Mon Dec  6 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_2
- updated to 0.7.32-2, using PREEMPT_DESKTOP

* Fri Dec  3 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.32_0
- updated to 0.7.32-0, using PREEMPT_DESKTOP

* Thu Dec  2 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.31_20
- updated to 0.7.31-20, using PREEMPT_DESKTOP

* Wed Dec  1 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.31_19
- updated to 0.7.31-19, using PREEMPT_DESKTOP
- go back to 4KSTACKS=n, that is the default in the latest fc2 errata kernel
- readded source statements for the .ccrma.config files, they got
  erased somehow

* Tue Nov 30 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rdtV0.7.31_15
- updated to 0.7.31-15
- configured with PREEMPT_DESKTOP

* Mon Nov 29 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rV0.7.31_13
- back to latest patch
- updated to the latest spec file from fedora core 2 (2.6.9-1.6.FC2)
- updated to 0.7.31-13
- options:
Preemption Mode
  1. No Forced Preemption (Server) (PREEMPT_NONE) (NEW)
> 2. Voluntary Kernel Preemption (Desktop) (PREEMPT_VOLUNTARY)
  3. Preemptible Kernel (Low-Latency Desktop) (PREEMPT_DESKTOP) (NEW)
  4. Complete Preemption (Real-Time) (PREEMPT_RT) (NEW)
choice[1-4]: 3
Old-Style Big Kernel Lock (SPINLOCK_BKL) [N/y/?] (NEW) ? y
  Real Time Clock Histogram Support (RTC_HISTOGRAM) [Y/n/m/?] (NEW) m
Priority Inheritance Debugging (Blocker) Device Support (BLOCKER) [Y/n/m/?] (NEW) m
Debug preemptible kernel (DEBUG_PREEMPT) [Y/n/?] (NEW) y
Wakeup latency timing (WAKEUP_TIMING) [Y/n/?] (NEW) y
Non-preemptible critical section latency timing (CRITICAL_PREEMPT_TIMING) [N/y/?] (NEW) n
Interrupts-off critical section latency timing (CRITICAL_IRQSOFF_TIMING) [N/y/?] (NEW) n

- detailed comparison with the latest Fedora Core 2 kernel configuration:
  start with i686 configuration:

Kernel Userspace Events (KOBJECT_UEVENT) [Y/n/?] (NEW) y
  Source checksum for all modules (MODULE_SRCVERSION_ALL) [N/y/?] (NEW) n
Processor family
  1. 386 (M386)
  2. 486 (M486)
  3. 586/K5/5x86/6x86/6x86MX (M586)
  4. Pentium-Classic (M586TSC)
  5. Pentium-MMX (M586MMX)
> 6. Pentium-Pro (M686)
  7. Pentium-II/Celeron(pre-Coppermine) (MPENTIUMII)
  8. Pentium-III/Celeron(Coppermine)/Pentium-III Xeon (MPENTIUMIII)
  9. Pentium M (MPENTIUMM)
  10. Pentium-4/Celeron(P4-based)/Pentium-4 M/Xeon (MPENTIUM4)
  11. K6/K6-II/K6-III (MK6)
  12. Athlon/Duron/K7 (MK7)
  13. Opteron/Athlon64/Hammer/K8 (MK8)
  14. Crusoe (MCRUSOE)
  15. Efficeon (MEFFICEON) (NEW)
  16. Winchip-C6 (MWINCHIPC6)
  17. Winchip-2 (MWINCHIP2)
  18. Winchip-2A/Winchip-3 (MWINCHIP3D)
  19. CyrixIII/VIA-C3 (MCYRIXIII)
  20. VIA C3-2 (Nehemiah) (MVIAC3_2)
choice[1-20]: 6
Preemption Mode
  1. No Forced Preemption (Server) (PREEMPT_NONE) (NEW)
> 2. Voluntary Kernel Preemption (Desktop) (PREEMPT_VOLUNTARY)
  3. Preemptible Kernel (Low-Latency Desktop) (PREEMPT_DESKTOP) (NEW)
  4. Complete Preemption (Real-Time) (PREEMPT_RT) (NEW)
choice[1-4]: 3
Thread Softirqs (PREEMPT_SOFTIRQS) [N/y/?] (NEW) y
Thread Hardirqs (PREEMPT_HARDIRQS) [N/y/?] (NEW) y
Old-Style Big Kernel Lock (SPINLOCK_BKL) [N/y/?] (NEW) y
Performance monitoring counters support (PERFCTR) [N/y/?] (NEW) y
  Init-time hardware tests (PERFCTR_INIT_TESTS) [N/y/?] (NEW) n
  Virtual performance counters support (PERFCTR_VIRTUAL) [Y/n/?] (NEW) y
Physical address where the kernel is loaded (1-112)MB (KERN_PHYS_OFFSET) [1] (NEW) 1
  kernel crash dumps (EXPERIMENTAL) (CRASH_DUMP) [N/y/?] (NEW) n
  Video (ACPI_VIDEO) [M/n/y/?] (NEW) m
  IBM ThinkPad Laptop Extras (ACPI_IBM) [M/n/y/?] (NEW) m
ACPI0004,PNP0A05 and PNP0A06 Container Driver (EXPERIMENTAL) (ACPI_CONTAINER) [N/m/y/?] (NEW) m
  Enable CPUfreq debugging (CPU_FREQ_DEBUG) [N/y/?] (NEW) n
  Built-in tables for Banias CPUs (X86_SPEEDSTEP_CENTRINO_TABLE) [Y/n/?] (NEW) n
nVidia nForce2 FSB changing (X86_CPUFREQ_NFORCE2) [N/m/y/?] (NEW) m
PCCard (PCMCIA/CardBus) support (PCCARD) [N/m/y/?] (NEW) m
  Enable PCCARD debugging (PCMCIA_DEBUG) [N/y/?] (NEW) n
  Enable obsolete PCCARD code (PCMCIA_OBSOLETE) [N/y/?] (NEW) n
  16-bit PCMCIA support (PCMCIA) [M/n/?] (NEW) m
  32-bit CardBus support (CARDBUS) [Y/n/?] (NEW)
CardBus yenta-compatible bridge support (YENTA) [N/m/?] (NEW) m
Cirrus PD6729 compatible bridge support (PD6729) [N/m/?] (NEW) m
i82092 compatible bridge support (I82092) [N/m/?] (NEW) m
i82365 compatible bridge support (I82365) [N/m/?] (NEW) m
Databook TCIC host bridge support (TCIC) [N/m/?] (NEW) m
JEDEC Flash device mapped on Technologic Systems TS-5500 (MTD_TS5500) [N/m/?] (NEW) m
  Support for PCMCIA management for PC-style ports (PARPORT_PC_PCMCIA) [N/m/?] (NEW) m
  Plug and Play ACPI support (EXPERIMENTAL) (PNPACPI) [Y/n/?] (NEW) y
Source directory of cpio_list (INITRAMFS_SOURCE) [] (NEW) 
Packet writing on CD/DVD media (CDROM_PKTCDVD) [N/m/y/?] (NEW) m
  Free buffers for data gathering (CDROM_PKTCDVD_BUFFERS) [8] (NEW) 8
  Enable write caching (CDROM_PKTCDVD_WCACHE) [N/y/?] (NEW) n
CFQ I/O scheduler (IOSCHED_CFQ) [Y/n/m/?] (NEW) y
    PCMCIA IDE support (BLK_DEV_IDECS) [N/m/?] (NEW) m
  iSCSI Transport Attributes (SCSI_ISCSI_ATTRS) [N/m/?] (NEW) m
  LSI Logic New Generation RAID Device Drivers (MEGARAID_NEWGEN) [N/y/?] (NEW) ? y
    LSI Logic Management Module (New Driver) (MEGARAID_MM) [N/m/?] (NEW) m
      LSI Logic MegaRAID Driver (New Driver) (MEGARAID_MAILBOX) [N/m/?] (NEW) m
    ULi Electronics SATA support (SCSI_SATA_ULI) [N/m/y/?] (NEW) m
    Qlogic QLA 1020/1040 SCSI support (SCSI_QLOGIC_1280_1040) [N/y/?] (NEW) y
  Adaptec AHA152X PCMCIA support (PCMCIA_AHA152X) [N/m/?] (NEW) m
  Future Domain PCMCIA support (PCMCIA_FDOMAIN) [N/m/?] (NEW)
  NinjaSCSI-3 / NinjaSCSI-32Bi (16bit) PCMCIA support (PCMCIA_NINJA_SCSI) [N/m/?] (NEW)
  Qlogic PCMCIA support (PCMCIA_QLOGIC) [N/m/?] (NEW)
  Symbios 53c500 PCMCIA support (PCMCIA_SYM53C500) [N/m/?] (NEW)
    Faulty test module for MD (MD_FAULTY) [N/m/y/?] (NEW) m
  IP: TCP socket monitoring interface (IP_TCPDIAG) [Y/n/m/?] (NEW) m
    Connection mark tracking support (IP_NF_CONNTRACK_MARK) [N/y/?] (NEW) y
      Connection mark match support (IP_NF_MATCH_CONNMARK) [N/m/?] (NEW) m
      hashlimit match support (IP_NF_MATCH_HASHLIMIT) [N/m/?] (NEW) m
      CONNMARK target support (IP_NF_TARGET_CONNMARK) [N/m/?] (NEW) m
    CLUSTERIP target support (EXPERIMENTAL) (IP_NF_TARGET_CLUSTERIP) [N/m/?] (NEW) n
    Packet scheduler clock source
    > 1. Timer interrupt (NET_SCH_CLK_JIFFIES) (NEW)
      2. gettimeofday (NET_SCH_CLK_GETTIMEOFDAY) (NEW)
      3. CPU cycle counter (NET_SCH_CLK_CPU) (NEW)
    choice[1-3?]: 1
  HCI DTL1 (PC Card) driver (BT_HCIDTL1) [N/m/?] (NEW) m
  HCI BT3C (PC Card) driver (BT_HCIBT3C) [N/m/?] (NEW) m
  HCI BlueCard (PC Card) driver (BT_HCIBLUECARD) [N/m/?] (NEW) m
  HCI UART (PC Card) device driver (BT_HCIBTUART) [N/m/?] (NEW) m
    Xircom CardBus support (new driver) (PCMCIA_XIRCOM) [N/m/y/?] (NEW) m
    Xircom Tulip-like CardBus support (old driver) (PCMCIA_XIRTULIP) [N/m/y/?] (NEW) m
    VLAN support (R8169_VLAN) [N/y/?] (NEW) y
    Use 2 Buffer Mode on Rx side. (2BUFF_MODE) [N/y/?] (NEW) n
    AT&T/Lucent old WaveLAN Pcmcia wireless support (PCMCIA_WAVELAN) [N/m/?] (NEW) m
    Xircom Netwave AirSurfer Pcmcia wireless support (PCMCIA_NETWAVE) [N/m/?] (NEW) m
    Aviator/Raytheon 2.4MHz wireless support (PCMCIA_RAYCS) [N/m/?] (NEW) m
    Hermes PCMCIA card support (PCMCIA_HERMES) [N/m/?] (NEW) m
    Cisco/Aironet 34X/35X/4500/4800 PCMCIA cards (AIRO_CS) [N/m/?] (NEW) m
    Atmel at76c502/at76c504 PCMCIA cards (PCMCIA_ATMEL) [N/m/?] (NEW) m
    Planet WL3501 PCMCIA cards (PCMCIA_WL3501) [N/m/?] (NEW) m
    IEEE 802.11 for Host AP (Prism2/2.5/3 and WEP/TKIP/CCMP) (HOSTAP) [N/m/y/?] (NEW) m
      IEEE 802.11 WEP encryption (HOSTAP_WEP) [N/m/?] (NEW) m
      IEEE 802.11 TKIP encryption (HOSTAP_TKIP) [N/m/?] (NEW) m
      IEEE 802.11 CCMP encryption (HOSTAP_CCMP) [N/m/?] (NEW) m
      Support downloading firmware images with Host AP driver (HOSTAP_FIRMWARE) [N/y/?] (NEW) y
      Host AP driver for Prism2/2.5/3 in PLX9052 PCI adaptors (HOSTAP_PLX) [N/m/?] (NEW)
      Host AP driver for Prism2.5 PCI adaptors (HOSTAP_PCI) [N/m/?] (NEW)
      Host AP driver for Prism2/2.5/3 PC Cards (HOSTAP_CS) [N/m/?] (NEW)
  PCMCIA network device support (NET_PCMCIA) [N/y/?] (NEW) y
    3Com 3c589 PCMCIA support (PCMCIA_3C589) [N/m/?] (NEW) m
    3Com 3c574 PCMCIA support (PCMCIA_3C574) [N/m/?] (NEW) m
    Fujitsu FMV-J18x PCMCIA support (PCMCIA_FMVJ18X) [N/m/?] (NEW) m
    NE2000 compatible PCMCIA support (PCMCIA_PCNET) [N/m/?] (NEW) m
    New Media PCMCIA support (PCMCIA_NMCLAN) [N/m/?] (NEW) m
    SMC 91Cxx PCMCIA support (PCMCIA_SMC91C92) [N/m/?] (NEW) m
    Xircom 16-bit PCMCIA support (PCMCIA_XIRC2PS) [N/m/?] (NEW) m
    Asix AX88190 PCMCIA support (PCMCIA_AXNET) [N/m/?] (NEW) m
    IBM PCMCIA tokenring adapter support (PCMCIA_IBMTR) [N/m/?] (NEW) m
    Support isdn diversion services (ISDN_DIVERSION) [N/m/?] (NEW) m
      Sedlbauer PCMCIA cards (HISAX_SEDLBAUER_CS) [N/m/?] (NEW) m
      ELSA PCMCIA MicroLink cards (HISAX_ELSA_CS) [N/m/?] (NEW) m
      AVM A1 PCMCIA cards (HISAX_AVM_A1_CS) [N/m/?] (NEW) m
      TELES PCMCIA cards (HISAX_TELES_CS) [N/m/?] (NEW) m
        AVM B1/M1/M2 PCMCIA cs module (ISDN_DRV_AVMB1_AVM_CS) [N/m/?] (NEW) m
  8250/16550 PCMCIA device support (SERIAL_8250_CS) [N/m/?] (NEW) m
  Real Time Clock Histogram Support (RTC_HISTOGRAM) [Y/n/m/?] (NEW) m
Priority Inheritance Debugging (Blocker) Device Support (BLOCKER) [Y/n/m/?] (NEW) m
SyncLink PC Card support (SYNCLINK_CS) [N/m/?] (NEW) m
    SMBus multiplexing on the Tyan S4882 (I2C_AMD756_S4882) [N/m/?] (NEW) m
  I2C/SMBus Test Stub (I2C_STUB) [N/m/?] (NEW) m
  National Semiconductor LM63 (SENSORS_LM63) [N/m/?] (NEW) m
  National Semiconductor LM87 (SENSORS_LM87) [N/m/?] (NEW) m
  National Semiconductor PC87360 family (SENSORS_PC87360) [N/m/?] (NEW) m
    DiBcom USB DVB-T devices (see help for device list) (DVB_DIBUSB) [N/m/?] (NEW) m
      Enable support for some Artec T1 device, which identifies as AN2235 (DVB_DIBUSB_MISDESIGNED_AN2235) [N/y/?] (NEW) y
      Enable extended debug support for DiBcom USB device (DVB_DIBCOM_DEBUG) [N/y/?] (NEW) n
    Terratec CinergyT2/qanu USB2 DVB-T receiver (DVB_CINERGYT2) [N/m/?] (NEW) m
      sophisticated fine-tuning for CinergyT2 cards (DVB_CINERGYT2_TUNING) [N/y/?] (NEW) n
    Philips TDA8044 or TDA8083 based (DVB_TDA80XX) [N/m/?] (NEW)
    Conexant cx22702 demodulator (OFDM) (DVB_CX22702) [N/m/?] (NEW)
  Enable Tile Blitting Support (FB_TILEBLITTING) [N/y/?] (NEW)
  Intel 830M/845G/852GM/855GM/865G support (EXPERIMENTAL) (FB_INTEL) [N/m/y/?] (NEW) m
    Intel driver Debug Messages (FB_INTEL_DEBUG) [N/y/?] (NEW) n
      Mach64 generic LCD support (EXPERIMENTAL) (FB_ATY_GENERIC_LCD) [N/y/?] (NEW) y
  S3 Savage support (FB_SAVAGE) [N/m/y/?] (NEW) m
    Enable DDC2 Support (FB_SAVAGE_I2C) [N/m/?] (NEW) m
    Enable Console Acceleration (FB_SAVAGE_ACCEL) [N/m/?] (NEW) m
  Bt87x Audio overclocking (SND_BT87X_OVERCLOCK) [N/y/?] (NEW) y
Digigram VXpocket (SND_VXPOCKET) [N/m/?] (NEW) m
Digigram VXpocket 440 (SND_VXP440) [N/m/?] (NEW) m
Sound Core PDAudioCF (SND_PDAUDIOCF) [N/m/?] (NEW) m
  KT Technology KC2190 based cables (InstaNet) (USB_KC2190) [Y/n/?] (NEW) y
  USB Cypress M8 USB Serial Driver (USB_SERIAL_CYPRESS_M8) [N/m/?] (NEW) m
  USB IPWireless (3G UMTS TDD) Driver (EXPERIMENTAL) (USB_SERIAL_IPW) [N/m/?] (NEW)
USB PhidgetKit support (USB_PHIDGETKIT) [N/m/y/?] (NEW)
Reiser4 (EXPERIMENTAL very fast general purpose filesystem) (REISER4_FS) [N/m/y/?] (NEW) n
General filesystem cache manager (FSCACHE) [N/m/y/?] (NEW) m
  Filesystem caching filesystem (CACHEFS) [N/m/?] (NEW) m
  JFFS2 support for ECC'd NOR flash (EXPERIMENTAL) (JFFS2_FS_NOR_ECC) [N/y/?] (NEW) y
Debug preemptible kernel (DEBUG_PREEMPT) [Y/n/?] (NEW) y
Wakeup latency timing (WAKEUP_TIMING) [Y/n/?] (NEW) y
Non-preemptible critical section latency timing (CRITICAL_PREEMPT_TIMING) [N/y/?] (NEW) y
Interrupts-off critical section latency timing (CRITICAL_IRQSOFF_TIMING) [N/y/?] (NEW) y
  Latency tracing (LATENCY_TRACE) [N/y/?] (NEW) y
kobject debugging (DEBUG_KOBJECT) [N/y/?] (NEW) n
Compile the kernel with frame pointers (USE_FRAME_POINTER) [N/y/?] (NEW) y
Use 4Kb for kernel stacks instead of 8Kb (4KSTACKS) [N/y/?] (NEW) y
Include kgdb kernel debugger (KGDB) [N/y/?] (NEW) n
Enable access key retention support (KEYS) [N/y/?] (NEW) n
  BSD Secure Levels (SECURITY_SECLVL) [N/m/y/?] (NEW) n
  Anubis cipher algorithm (CRYPTO_ANUBIS) [N/m/y/?] (NEW) m

- for smp kernels:

Cpuset support (CPUSETS) [N/y/?] (NEW) n

- made a diff of the changes and edited it by hand:

  deleted proc config.gz support (more memory used, no gain)
  kept UP APIC support
  kept CONFIG_EDD
  kept CONFIG_MTD_AMD76XROM=m and MTD_L440GX=m
  kept CONFIG_BLK_DEV_IDETAPE=m
  kept CONFIG_SERIO_RAW=m
  removed CONFIG_PRIME_SOUND and friends
  kept CONFIG_NTFS_FS=m
  kept CONFIG_SECURITY_CAPABILITIES=m and CONFIG_SECURITY_REALTIME

- after the diff:

Message Signaled Interrupts (MSI and MSI-X) (PCI_MSI) [N/y/?] (NEW) n
  IBM PCI Hotplug driver (HOTPLUG_PCI_IBM) [N/m/y/?] (NEW) n

* Sat Nov 27 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.10rc2mm3_vT3.ll
- branch to the old voluntary preemption T3 on top of 2.6.10-rc2-mm3
- grep PREEMPT in .config:
CONFIG_PREEMPT_TIMING=y
CONFIG_PREEMPT=y
CONFIG_PREEMPT_BKL=y
CONFIG_PREEMPT_VOLUNTARY=y
CONFIG_PREEMPT_SOFTIRQS=y
CONFIG_PREEMPT_HARDIRQS=y
CONFIG_DEBUG_PREEMPT=y

* Sat Nov 27 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rV0.7.31_9.ll
- updated to 0.7.31-9
- keep it configured as PREEMPT_DESKTOP

* Wed Nov 24 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.1.rV0.7.31_3.ll
- updated to 0.7.31-3 and 2.6.10-rc2-mm3
- configure it as PREEMPT_DESKTOP
- options:
      Enable support for some Artec T1 device, which identifies as AN2235 (DVB_DIBUSB_MISDESIGNED_AN2235) [N/y/?] (NEW) y
      Enable extended debug support for DiBcom USB device (DVB_DIBCOM_DEBUG) [N/y/?] (NEW) n
        Status update interval [milliseconds] (DVB_CINERGYT2_QUERY_INTERVAL) [250] (NEW) 250
    Philips TDA8044 or TDA8083 based (DVB_TDA80XX) [N/m/?] (NEW) m
- !!! later: configure it as PREEMPT_VOLUNTARY to test the base system without the rt changes
- !!! disable smp build temporarily

* Tue Nov 23 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.30_9.ll
- updated to 0.7.30-9
- configure it as PREEMPT_DESKTOP
- options:
Priority Inheritance Debugging (Blocker) Device Support (BLOCKER) [Y/n/m/?] (NEW) m

* Fri Nov 19 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.29_4.ll
- updated to 0.7.29-4
- keep PREEMPT_RT configuration for now
XIP aware MTD support (MTD_XIP) [N/y/?] (NEW) n
  iSCSI Transport Attributes (SCSI_ISCSI_ATTRS) [N/m/?] (NEW) m
  IPMI sockets (IPMI_SOCKET) [N/m/?] (NEW) m
    Support isdn diversion services (ISDN_DIVERSION) [N/m/?] (NEW) m
  JFFS2 support for ECC'd NOR flash (EXPERIMENTAL) (JFFS2_FS_NOR_ECC) [N/y/?] (NEW) y

* Thu Nov 18 2004 Dave Jones <davej@redhat.com>
- Drop 2.6.9 changes that broke megaraid. (#139723)
- Update to 2.6.9-ac10, fixing the SATA problems (#139674)
- Update the OOM-killer tamer to upstream.
- Implement an RCU scheme for the SELinux AVC
- Improve on the OOM-killer taming patch.
- device-mapper: Remove duplicate kfree in dm_register_target error path.
- Make SHA1 guard against misaligned accesses
- ASPM workaround for PCIe. (#123360)
- Hot-plug driver updates due to MSI change (#134290)
- Workaround for 80332 IOP hot-plug problem (#139041)
- ExpressCard hot-plug support for ICH6M (#131800)
- Fix boot crash on VIA systems (noted on x86-64)
- PPC64: Store correct backtracking info in ppc64 signal frames
- PPC64: Prevent HVSI from oopsing on hangup (#137912)
- Fix poor performance b/c of noncacheable mapping in 4g/4g (#130842)
- Fix PCI-X hotplug issues (#132852, #134290)
- Re-export force_sig() (#139503)
- Various fixes for more security issues from latest -ac patch.
- Fix d_find_alias brokenness (#137791)
- tg3: Fix fiber hw autoneg bounces (#138738)
- diskdump: Fix issue with NMI watchdog. (#138041)
- diskdump: Export disk_dump_state. (#138132)
- diskdump: Tickle NMI watchdog in diskdump_mdelay() (#138036)
- diskdump: Fix mem= for x86-64 (#138139)
- diskdump: Fix missing system_state setting. (#138130)
- diskdump: Fix diskdump completion message (#138028)
- Re-add aic host raid support.
- Take a few more export removal patches from 2.6.10rc
- SATA: Make AHCI work
- SATA: Core updates.
- S390: Fix Incorrect registers in core dumps. (#138206)
- S390: Fix up lcs device state. (#131167)
- S390: Fix possible qeth IP registration failure.
- S390: Support broadcast on z800/z900 HiperSockets
- S390: Allow FCP port to recover after aborted nameserver request.
- Flush error in pci_mmcfg_write (#129338)
- hugetlb_get_unmapped_area fix (#135364, #129525)
- Fix ia64 cyclone timer on ia64 (#137842, #136684)
- Fix ipv6 MTU calculation. (#130397)
- ACPI: Don't display messages about ACPI breakpoints. (#135856)
- Fix x86_64 copy_user_generic (#135655)
- lockd: remove hardcoded maximum NLM cookie length
- Fix SCSI bounce limit
- Disable polling mode on hotplug controllers in favour of interrupt driven. (#138737)

* Wed Nov 17 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.28_0.ll
- updated to 0.7.28-0
- tried with PREEMPT_RT instead of PREEMPT_DESKTOP

* Tue Nov 16 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.27_11.ll
- updated to 0.7.27-6, on top of 2.6.10-rc2-mm1
    Use 2 Buffer Mode on Rx side. (2BUFF_MODE) [N/y/?] (NEW) n
    IEEE 802.11 for Host AP (Prism2/2.5/3 and WEP/TKIP/CCMP) (HOSTAP) [N/m/y/?] (NEW) m
      IEEE 802.11 WEP encryption (HOSTAP_WEP) [N/m/?] (NEW) m
     IEEE 802.11 TKIP encryption (HOSTAP_TKIP) [N/m/?] (NEW) m
      IEEE 802.11 CCMP encryption (HOSTAP_CCMP) [N/m/?] (NEW) m
      Support downloading firmware images with Host AP driver (HOSTAP_FIRMWARE) [N/y/?] (NEW) y
      Host AP driver for Prism2/2.5/3 in PLX9052 PCI adaptors (HOSTAP_PLX) [N/m/?] (NEW) m
      Host AP driver for Prism2.5 PCI adaptors (HOSTAP_PCI) [N/m/?] (NEW) m
      Host AP driver for Prism2/2.5/3 PC Cards (HOSTAP_CS) [N/m/?] (NEW) m
    SMBus multiplexing on the Tyan S4882 (I2C_AMD756_S4882) [N/m/?] (NEW) m
  National Semiconductor LM63 (SENSORS_LM63) [N/m/?] (NEW) m
  National Semiconductor PC87360 family (SENSORS_PC87360) [N/m/?] (NEW) m
    NSA SELinux AVC Statistics (SECURITY_SELINUX_AVC_STATS) [Y/n/?] (NEW) y
  Anubis cipher algorithm (CRYPTO_ANUBIS) [N/m/y/?] (NEW) m
- updated to 0.7.27-10
- updated to 0.7.27-11

* Mon Nov 15 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.26_5.ll
- updated to 0.7.26-5

* Sat Nov 13 2004 Dave Jones <davej@redhat.com>
- Drop some bogus patches.

* Fri Nov 12 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.26_0.ll
- updated to 0.7.26-0

Options (interesting!)
Preemption Mode
  1. No Forced Preemption (Server) (PREEMPT_NONE) (NEW)
  2. Voluntary Kernel Preemption (Desktop) (PREEMPT_VOLUNTARY) (NEW)
  3. Preemptible Kernel (Low-Latency Desktop) (PREEMPT_DESKTOP) (NEW)
> 4. Complete Preemption (Real-Time) (PREEMPT_RT) 3
Old-Style Big Kernel Lock (SPINLOCK_BKL) [N/y/?] (NEW) ? n
  Real Time Clock Histogram Support (RTC_HISTOGRAM) [Y/n/m/?] (NEW) m
Non-preemptible critical section latency timing (CRITICAL_PREEMPT_TIMING) [N/y/?] (NEW) y
Interrupts-off critical section latency timing (CRITICAL_IRQSOFF_TIMING) [N/y/?] (NEW) y
Include kgdb kernel debugger (KGDB) [N/y/?] (NEW) ? n

* Thu Nov 11 2004 Dave Jones <davej@redhat.com>
- NFS: Fix dentry refcount accounting error
- Fix single-stepping on PPC64
- Integrate kernel-devel changes
- SELinux: netif fixes.
- SELinux: add DAC check to setxattr() hook.
- SELinux: sidtab locking fix.
- SELinux: mediate send_sigurg().
- SELinux: fix setscheduler hook deadlock.
- ide-floppy: Supresses error messages resulting from Medium not present
- Various IA64 updates from 2.6.10rc1
- nfsd: make sure getxattr inode op is non-NULL before calling it.
- Handle NULL dev->dev_addr in SIOCGIFHWADDR correctly. (#137648)
- Fix NFSD domainname size limit.
- nfsd4: nfsd oopsed when encountering a conflict with a local lock
- nfsd4: fix putrootfh return
- nfsd: Insecure port warning shows decimal IPv4 address
- Disable sw irqbalance/irqaffinity for e7520/e7320/e7525 (#136419)
- Fix exec-shield non-PIE/non-prelinked bug
- ext3 reservations: fix goal hit accounting.
- Fix problems with non-power-of-two sector size discs. (#135094)
- Fix possible oops in netpoll (#132153)
- Add missing MODULE_VERSION tags to various modules. (#136399)
- Add USB card reader de jour. (#124048)
- Remove SG_IO deprecation warning (#136179)
- Make sure that modules get signed with the right key.
- Remove SG_IO deprecation warning (#136179)
- s390: Fix fake_ll for qeth device. (#136175)
- s390: zfcp: Kernel stack frame for zfcp_cfdc_dev_ioctl() is too big
- s390: Use slab allocator for DASD I/O pages.
- PPC64: HVSI udbg support
- PPC64: Make HVSI console survive FSP reset
- PPC64: Make PCI hostbridge hotplugging work
- PPC64: Fix IBM VSCSI problems (#138124)
- Rebase -ac patch to 2.6.9-ac8.

* Wed Nov 10 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.24.ll
- updated to 0.7.24
 Real-Time Kernel Preemption (PREEMPT_RT) [Y/n/?] (NEW) y
    Faulty test module for MD (MD_FAULTY) [N/m/y/?] (NEW) n
  IP: TCP socket monitoring interface (IP_TCPDIAG) [Y/n/m/?] (NEW) ? m
  iptables Actions (NET_ACT_IPT) [N/m/?] (NEW) ? m
  KT Technology KC2190 based cables (InstaNet) (USB_KC2190) [Y/n/?] (NEW) y
  USB Cypress M8 USB Serial Driver (USB_SERIAL_CYPRESS_M8) [N/m/?] (NEW) m
Wakeup latency timing (WAKEUP_TIMING) [Y/n/?] (NEW) ? y

[root@localhost PLANET]# rpm -ivh --oldpackage 2/kernel-2.6.9-1.520.1rV0.7.24.ll.rhfc2.ccrma.i686.rpm
Preparing...                ########################################### [100%]
   1:kernel                 ########################################### [100%]
WARNING: /lib/modules/2.6.9-1.520.1rV0.7.24.ll.rhfc2.ccrma/kernel/drivers/acpi/container.ko needs unknown symbol hotplug_path

* Mon Nov  8 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.22.ll
- updated to 0.7.22, now on top of 2.6.10-rc1-mm3

* Thu Nov  4 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.11.ll
- updated to V0.7.10
Automatic mutex/rwsem deadlock detection (RT_DEADLOCK_DETECT) [Y/n/?] (NEW) ? y
- and then to V0.7.11

* Wed Nov  3 2004 Dave Jones <davej@redhat.com>
- Reenable token-ring drivers (#122602)

* Wed Nov  3 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.7.7.ll
- updated to V0.7.7
- builds on top of 2.6.10-rc1-mm2
- see below: disabled 4KSTACKS for now...
- fixed CONFIG_INITRAMFS_SOURCE in smp configurations, was for some
  reason ="n" (should be ="")
- options:

  Video (ACPI_VIDEO) [M/n/y/?] (NEW) m
  IBM ThinkPad Laptop Extras (ACPI_IBM) [M/n/y/?] (NEW) m
ACPI0004,PNP0A05 and PNP0A06 Container Driver (EXPERIMENTAL) (ACPI_CONTAINER) [N/m/y/?] (NEW) m
  Enable CPUfreq debugging (CPU_FREQ_DEBUG) [N/y/?] (NEW) n
  Plug and Play ACPI support (EXPERIMENTAL) (PNPACPI) [Y/n/?] (NEW) n
    Connection mark tracking support (IP_NF_CONNTRACK_MARK) [N/y/?] (NEW) y
      Connection mark match support (IP_NF_MATCH_CONNMARK) [N/m/?] (NEW) m
      hashlimit match support (IP_NF_MATCH_HASHLIMIT) [N/m/?] (NEW) m
      CONNMARK target support (IP_NF_TARGET_CONNMARK) [N/m/?] (NEW) m
    CLUSTERIP target support (EXPERIMENTAL) (IP_NF_TARGET_CLUSTERIP) [N/m/?] (NEW) n
  Generic Packet Editor Actions (NET_ACT_PEDIT) [N/m/y/?] (NEW) m
    Terratec CinergyT2/qanu USB2 DVB-T receiver (DVB_CINERGYT2) [N/m/?] (NEW) m
      sophisticated fine-tuning for CinergyT2 cards (DVB_CINERGYT2_TUNING) [N/y/?] (NEW) y
        Number of queued USB Request Blocks for Highspeed Stream Transfers (DVB_CINERGYT2_STREAM_URB_COUNT) [32] (NEW) 32
        Size of URB Stream Buffers for Highspeed Transfers (DVB_CINERGYT2_STREAM_BUF_SIZE) [512] (NEW) 512
        Register the onboard IR Remote Control Receiver as Input Device (DVB_CINERGYT2_ENABLE_RC_INPUT_DEVICE) [N/y/?] (NEW) n
  Intel 830M/845G/852GM/855GM/865G support (EXPERIMENTAL) (FB_INTEL) [N/m/y/?] (NEW) m
    Intel driver Debug Messages (FB_INTEL_DEBUG) [N/y/?] (NEW) n
  S3 Savage support (FB_SAVAGE) [N/m/y/?] (NEW) m
    Enable DDC2 Support (FB_SAVAGE_I2C) [N/m/?] (NEW) m
    Enable Console Acceleration (FB_SAVAGE_ACCEL) [N/m/?] (NEW) m
Use 4Kb for kernel stacks instead of 8Kb (4KSTACKS) [N/y/?] (NEW) n

* Tue Nov  2 2004 Dave Jones <davej@redhat.com>
- Reenable SLIP. (#124223)
- Add USB card reader de jour. (#124048)

* Tue Nov  2 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rV0.6.9.ll
- realtime-preemption V0.6.9
- reenabled CONFIG_TRACE_LATENCY (compilation fails otherwise)
Compile the kernel with frame pointers (USE_FRAME_POINTER) [Y/n/?] (NEW) y

* Mon Nov  1 2004 Dave Jones <davej@redhat.com>
- Fix memory leak on x86-64 in mixed 32/64 mode. (#132947)
- Yet another USB card reader for the whitelist. (#137722)

* Fri Oct 29 2004 Dave Jones <davej@redhat.com>
- Fix raid5 oops (#127862)
- Stop E820 BIOS entries being corrupted by EDID info. (#137510)

* Thu Oct 28 2004 Dave Jones <davej@redhat.com>
- Remove the possibility of some false OOM kills. (#131251)
- Add more USB card readers to SCSI whitelist (#131546)
- Disable CONFIG_SCHED_SMT for iseries.

* Wed Oct 27 2004 Dave Jones <davej@redhat.com>
- Reenable ISA NIC support (#136569)

* Tue Oct 26 2004 Dave Jones <davej@redhat.com>
- Reenable Initio 9100U(W) SCSI driver. (#137153)

* Mon Oct 25 2004 Dave Jones <davej@redhat.com>
- Add another USB card reader to SCSI whitelist (#132923)

* Fri Oct 22 2004 Dave Jones <davej@redhat.com>
- Fix PPC NUMA (#130716).
- Fix autoraid for S390 (#123842/#130339)
- Selected bits from 2.6.9-ac3
  - Fix syncppp/async ppp problems with new hangup
  - Fix broken parport_pc unload
  - Stop i8xx_tco making some boxes reboot on load
  - Fix cpia/module tools deadlock
  - Security fix for smbfs leak/overrun

* Fri Oct 22 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.9-1.520.1rU10.1.ll
- updated to 2.6.9-mm1 + U10.1
Function alignment (CC_ALIGN_FUNCTIONS) [0] (NEW) 0
Label alignment (CC_ALIGN_LABELS) [0] (NEW) 0
Loop alignment (CC_ALIGN_LOOPS) [0] (NEW) ? 0
Jump alignment (CC_ALIGN_JUMPS) [0] (NEW) 0
Processor family
  1. 386 (M386)
  2. 486 (M486)
  3. 586/K5/5x86/6x86/6x86MX (M586)
  4. Pentium-Classic (M586TSC)
  5. Pentium-MMX (M586MMX)
> 6. Pentium-Pro (M686)
  7. Pentium-II/Celeron(pre-Coppermine) (MPENTIUMII)
  8. Pentium-III/Celeron(Coppermine)/Pentium-III Xeon (MPENTIUMIII)
  9. Pentium M (MPENTIUMM)
  10. Pentium-4/Celeron(P4-based)/Pentium-4 M/Xeon (MPENTIUM4)
  11. K6/K6-II/K6-III (MK6)
  12. Athlon/Duron/K7 (MK7)
  13. Opteron/Athlon64/Hammer/K8 (MK8)
  14. Crusoe (MCRUSOE)
  15. Efficeon (MEFFICEON) (NEW)
  16. Winchip-C6 (MWINCHIPC6)
  17. Winchip-2 (MWINCHIP2)
  18. Winchip-2A/Winchip-3 (MWINCHIP3D)
  19. CyrixIII/VIA-C3 (MCYRIXIII)
  20. VIA C3-2 (Nehemiah) (MVIAC3_2)
choice[1-20]: 6
HPET Timer Support (HPET_TIMER) [N/y/?] (NEW) y
  Provide RTC interrupt (HPET_EMULATE_RTC) [N/y] (NEW) y
Physical address where the kernel is loaded (1-112)MB (KERN_PHYS_OFFSET) [1] (NEW) 1
PCCard (PCMCIA/CardBus) support (PCCARD) [N/m/y/?] (NEW) m
  Enable PCCARD debugging (PCMCIA_DEBUG) [N/y/?] (NEW) n
  Enable obsolete PCCARD code (PCMCIA_OBSOLETE) [N/y/?] (NEW) n
  16-bit PCMCIA support (PCMCIA) [M/n/?] (NEW) m
  32-bit CardBus support (CARDBUS) [Y/n/?] (NEW) y
CardBus yenta-compatible bridge support (YENTA) [N/m/?] (NEW) m
Cirrus PD6729 compatible bridge support (PD6729) [N/m/?] (NEW) m
i82092 compatible bridge support (I82092) [N/m/?] (NEW) m
i82365 compatible bridge support (I82365) [N/m/?] (NEW) m
Databook TCIC host bridge support (TCIC) [N/m/?] (NEW) m
JEDEC Flash device mapped on Technologic Systems TS-5500 (MTD_TS5500) [N/m/?] (NEW) m
  Support for PCMCIA management for PC-style ports (PARPORT_PC_PCMCIA) [N/m/?] (NEW) m
IEEE 1284 transfer modes (PARPORT_1284) [N/y/?] (NEW) ? y
    PCMCIA IDE support (BLK_DEV_IDECS) [N/m/?] (NEW) m
    IDE Taskfile IO (EXPERIMENTAL) (IDE_TASKFILE_IO) [N/y/?] (NEW) y
          Enable controller even if disabled by BIOS (PDC202XX_FORCE) [N/y/?] (NEW) n
    AHCI SATA support (SCSI_SATA_AHCI) [N/m/y/?] (NEW) m
  Adaptec AHA152X PCMCIA support (PCMCIA_AHA152X) [N/m/?] (NEW) m
  Future Domain PCMCIA support (PCMCIA_FDOMAIN) [N/m/?] (NEW) m
  NinjaSCSI-3 / NinjaSCSI-32Bi (16bit) PCMCIA support (PCMCIA_NINJA_SCSI) [N/m/?] (NEW) m
  Qlogic PCMCIA support (PCMCIA_QLOGIC) [N/m/?] (NEW) m
  Symbios 53c500 PCMCIA support (PCMCIA_SYM53C500) [N/m/?] (NEW) m
  Packet In/Egress redirecton/mirror Actions (NET_ACT_MIRRED) [N/m/y/?] (NEW) m
  HCI DTL1 (PC Card) driver (BT_HCIDTL1) [N/m/?] (NEW) m
  HCI BT3C (PC Card) driver (BT_HCIBT3C) [N/m/?] (NEW) m
  HCI BlueCard (PC Card) driver (BT_HCIBLUECARD) [N/m/?] (NEW) m
  HCI UART (PC Card) device driver (BT_HCIBTUART) [N/m/?] (NEW) m
    Xircom CardBus support (new driver) (PCMCIA_XIRCOM) [N/m/y/?] (NEW) m
    Xircom Tulip-like CardBus support (old driver) (PCMCIA_XIRTULIP) [N/m/y/?] (NEW) m
    AT&T/Lucent old WaveLAN Pcmcia wireless support (PCMCIA_WAVELAN) [N/m/?] (NEW) m
    Xircom Netwave AirSurfer Pcmcia wireless support (PCMCIA_NETWAVE) [N/m/?] (NEW) m
    Aviator/Raytheon 2.4MHz wireless support (PCMCIA_RAYCS) [N/m/?] (NEW) m
    Hermes PCMCIA card support (PCMCIA_HERMES) [N/m/?] (NEW) m
    Cisco/Aironet 34X/35X/4500/4800 PCMCIA cards (AIRO_CS) [N/m/?] (NEW) m
    Atmel at76c502/at76c504 PCMCIA cards (PCMCIA_ATMEL) [N/m/?] (NEW) m
   Planet WL3501 PCMCIA cards (PCMCIA_WL3501) [N/m/?] (NEW) m
  PCMCIA network device support (NET_PCMCIA) [N/y/?] (NEW) y
   3Com 3c589 PCMCIA support (PCMCIA_3C589) [N/m/?] (NEW) m
    3Com 3c574 PCMCIA support (PCMCIA_3C574) [N/m/?] (NEW) m
    Fujitsu FMV-J18x PCMCIA support (PCMCIA_FMVJ18X) [N/m/?] (NEW) m
    NE2000 compatible PCMCIA support (PCMCIA_PCNET) [N/m/?] (NEW) m
    New Media PCMCIA support (PCMCIA_NMCLAN) [N/m/?] (NEW) m
    SMC 91Cxx PCMCIA support (PCMCIA_SMC91C92) [N/m/?] (NEW) m
    Xircom 16-bit PCMCIA support (PCMCIA_XIRC2PS) [N/m/?] (NEW) m
    Asix AX88190 PCMCIA support (PCMCIA_AXNET) [N/m/?] (NEW) m
      Sedlbauer PCMCIA cards (HISAX_SEDLBAUER_CS) [N/m/?] (NEW) m
      ELSA PCMCIA MicroLink cards (HISAX_ELSA_CS) [N/m/?] (NEW) m
      AVM A1 PCMCIA cards (HISAX_AVM_A1_CS) [N/m/?] (NEW) m
      TELES PCMCIA cards (HISAX_TELES_CS) [N/m/?] (NEW) m
        AVM B1/M1/M2 PCMCIA cs module (ISDN_DRV_AVMB1_AVM_CS) [N/m/?] (NEW) m
  8250/16550 PCMCIA device support (SERIAL_8250_CS) [N/m/?] (NEW) m
SyncLink PC Card support (SYNCLINK_CS) [N/m/?] (NEW) m
  National Semiconductor LM87 (SENSORS_LM87) [N/m/?] (NEW) m
  W9966CF Webcam (FlyCam Supra and others) Video For Linux (VIDEO_W9966) [N/m/?] (NEW) m
    CPiA Parallel Port Lowlevel Support (VIDEO_CPIA_PP) [N/m/?] (NEW) m
      Mach64 generic LCD support (EXPERIMENTAL) (FB_ATY_GENERIC_LCD) [N/y/?] (NEW) y
Digigram VXpocket (SND_VXPOCKET) [N/m/?] (NEW) m
Digigram VXpocket 440 (SND_VXP440) [N/m/?] (NEW) m
Sound Core PDAudioCF (SND_PDAUDIOCF) [N/m/?] (NEW) m
  USB IPWireless (3G UMTS TDD) Driver (EXPERIMENTAL) (USB_SERIAL_IPW) [N/m/?] (NEW) m
USB PhidgetKit support (USB_PHIDGETKIT) [N/m/y/?] (NEW) m
  kobject debugging (DEBUG_KOBJECT) [N/y/?] (NEW) n

* Thu Oct 21 2004 Dave Jones <davej@redhat.com>
- Misc security fixes from 2.6.9-ac2

* Thu Oct 21 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8-1.520.1rU9.2.ll
- updated to U9.2

* Wed Oct 20 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8-1.520.1rU8.1.ll
- updated to U8.1

* Wed Oct 20 2004 Dave Jones <davej@redhat.com>
- Fix ia64 module loading. (#136365)
- Enable discontigmem for PPC64
- Disable a bunch of useless PPC config options
- Enable PACK_STACK on s390.

* Tue Oct 19 2004 Dave Jones <davej@redhat.com>
- Fix NFS badness (#132726)
- Drop bogus USB workaround. (#131127)

* Mon Oct 18 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8-1.520.1rU6.ll
- updated to realtime preempt U6 (name changed from voluntary preempt)
- and then to U7...
- options: why this now? only change was U7...
Reiser4 (EXPERIMENTAL very fast general purpose filesystem) (REISER4_FS) [N/m/y/?] (NEW) n

* Mon Oct 18 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8-1.520.1vU5.ll
- voluntary U5
- options:
Automatic mutex/rwsem deadlock detection (RWSEM_DEADLOCK_DETECT) [Y/n/?] (NEW) y
  Maximum number of rwsem owners tracked (1-128) (RWSEM_MAX_OWNERS) [64] (NEW) 64

* Mon Oct 18 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9
- Speedtouch USB DSL modem driver update.
- Cleanup some iseries config options.

* Fri Oct 15 2004 Dave Jones <davej@redhat.com>
- 2.6.9-rc4-bk3
- Fix up a bunch of unresolved symbols that crept in recently.
- Remove bogus O_NONBLOCK patch which broke lots of userspace.
- Fix booting on PPC64 by reserving initrd pages.

* Fri Oct 15 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8-1.520.1vU3.ll
- voluntary U3
- disable CONFIG_DEBUG_SPINLOCK* options in the configuration (otherwise
  we get build errors)

* Thu Oct 14 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8-1.520.1vU2.ll
- voluntary U2

* Thu Oct 14 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8-1.520.1vU1.ll
- voluntary U1 on top of 2.6.9rc4-mm1
- rebuilt chunk for rt patch

 Real-Time Kernel Preemption (PREEMPT_REALTIME) [N/y/?] (NEW) ? y
  Via unichrome video cards (DRM_VIA) [N/m/y/?] (NEW) ? m
  Bt87x Audio overclocking (SND_BT87X_OVERCLOCK) [N/y/?] (NEW) n

- does not build...

* Thu Oct 14 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4-bk2
- librtas needs to work around the /dev/mem restrictions.
- EXT3 reservations use-before-initialised bugfix.
- support O_NONBLOCK for read,pread,readv of regular files.
- EDD blows up some x86-64's. Disable again.

* Wed Oct 13 2004 Dave Jones <davej@redhat.com>
- Make EDD driver modular on x86-64 too.
- Various mkinitrd spec changes (Jeremy Katz)
- Enable a bunch more PPC64 config options. (Dave Howells)
- Enable ACPI cpufreq driver for x86-64 too.

* Tue Oct 12 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4-bk1
- Tux update.
- Update netdump/diskdump patches
- PowerPC 64 netboot changes.
- Various CONFIG_ option diddling.
- Fix up the find_isa_irq_pin() oops on reboot for x86-64 too. 

* Mon Oct 11 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4
- Enable CONFIG_MICROCODE for x86-64

* Fri Oct  8 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk8

* Thu Oct  7 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1vT3.ll
- up to voluntary T3, on top of rc3-mm3
- applied fix mentioned in mailing list
- match voluntary to that fix
- fix security/Makefile (in rt patch)

  Source checksum for all modules (MODULE_SRCVERSION_ALL) [N/y/?] (NEW) n
  EDD: Skip Master Boot Record read (EDD_SKIP_MBR) [N/y/?] (NEW) n
  Initio 9100U(W) support (SCSI_INITIO) [N/m/?] (NEW) m
  Qlogic QLA 1020/1040 SCSI support (SCSI_QLOGIC_1280_1040) [N/y/?] (NEW) y
General filesystem cache manager (FSCACHE) [N/m/y/?] (NEW) m
  Filesystem caching filesystem (CACHEFS) [N/m/?] (NEW) m
Debug preemptible kernel (DEBUG_PREEMPT) [Y/n/?] (NEW) y
  BSD Jail LSM (SECURITY_BSDJAIL) [N/m/y/?] (NEW) n

* Thu Oct  7 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk7
- Fix up PPC/PPC64 compilation failures due to new binutils. (David Woodhouse)

* Wed Oct  6 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk6
- Add xattr support for tmpfs.

* Tue Oct  5 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.2vS7.ll
- back to S7, T1 has problems booting
- removed ingo-blk patch (20334)
- options:
    IDE Taskfile IO (EXPERIMENTAL) (IDE_TASKFILE_IO) [N/y/?] (NEW) n
  Whirlpool digest algorithm (CRYPTO_WHIRLPOOL) [N/m/y/?] (NEW) m

- additional options readded (i686[-smp]):
access to kernel configuration through /proc
  CONFIG_IKCONFIG=y
  CONFIG_IKCONFIG_PROC=y
measure time spent in non-preemptible critical sections
  CONFIG_PREEMPT_TIMING=y
enable up apics (not on i586, not needed on SMP)
  CONFIG_UP_APIC=y
  CONFIG_UP_IOAPIC=y
frequency control for via chips
  CONFIG_X86_LONGHAUL=m
irq balancing (SMP only)
  CONFIG_IRQ_BALANCE

* Mon Oct  4 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vS9.ll
- updated to 2.6.9-rc3-mm2-S9
- eliminated wrong chunk from S9 that was hardwiring the main linux
  makefile to ARCH = x86_64

    ULi Electronics SATA support (SCSI_SATA_ULI) [N/m/y/?] (NEW) m
Preempt-unsafe smp_processor_id() checking (DEBUG_SMP_PROCESSOR_ID) [Y/n/?] (NEW) y
  BSD Secure Levels (SECURITY_SECLVL) [N/m/y/?] (NEW) n
  Whirlpool digest algorithms (CRYPTO_WP512) [N/m/y/?] (NEW) m

- options added (i686[-smp]):
access to kernel configuration through /proc
  CONFIG_IKCONFIG=y
  CONFIG_IKCONFIG_PROC=y
measure time spent in non-preemptible critical sections
  CONFIG_PREEMPT_TIMING=y
enable up apics (not on i586, not needed on SMP)
  CONFIG_UP_APIC=y
  CONFIG_UP_IOAPIC=y
frequency control for via chips
  CONFIG_X86_LONGHAUL=m
 
* Mon Oct  4 2004 Stephen C. Tweedie <sct@redhat.com>
- Update ext3 online resize to 2.6.9-rc3-mm2 upstream
- Reenable ext3 online resize in .spec

* Wed Sep 29 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vS7.ll
- added small patch by Ingo

* Tue Sep 28 2004 Jeremy Katz <katzj@redhat.com>
- add patch from Roland McGrath/James Morris to fix mprotect hook bug (#133505)

* Mon Sep 27 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vS7.ll
- updated to voluntary S6 on top of 2.6.9-rc2-mm4
  Performance counter overflow interrupt support (PERFCTR_INTERRUPT_SUPPORT) [N/y] (NEW) n
Source directory of cpio_list (INITRAMFS_SOURCE) [] (NEW)
      comment match support (IP_NF_MATCH_COMMENT) [N/m/?] (NEW) ? m

* Fri Sep 24 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vS6.ll
- updated to voluntary S6

* Thu Sep 23 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vS5.ll
- updated to voluntary S5
      Physdev match support (IP6_NF_MATCH_PHYSDEV) [N/m/?] (NEW) m
  I2C/SMBus Test Stub (I2C_STUB) [N/m/?] (NEW) n
    DVB Support for cx2388x based TV cards (VIDEO_CX88_DVB) [N/m/?] (NEW) m
    Conexant cx22702 demodulator (OFDM) (DVB_CX22702) [N/m/?] (NEW) m
   Zarlink MT352 based (DVB_MT352) [N/m/?] (NEW) m
   DiBcom 3000-MB (DVB_DIB3000MB) [N/m/?] (NEW) m
    Twinhan/KWorld/Hama/Artec USB DVB-T devices (DVB_DIBUSB) [N/m/?] (NEW) m
 tmpfs Extended Attributes (TMPFS_XATTR) [N/y/?] (NEW) n
- there are missing symbols in some modules

* Wed Sep 22 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vS3.ll
- updated to voluntary S3
  Preempt The Big Kernel Lock (PREEMPT_BKL) [Y/n/?] (NEW) y
- later... reverted to R9, could not boot S3 on an Athlon64
  Suspend-to-Disk Support (PM_DISK) [N/y/?] (NEW) n
  Gameport data dumper (INPUT_JOYDUMP) [N/m/y/?] (NEW) ? n

* Tue Sep 21 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vS2.ll
- rc2-mm1 + voluntary S0
- disabled several redhat original patches
- sysnice patch no longer patches cleanly

Local version - append to kernel release (LOCALVERSION) [] (NEW)
Kernel Userspace Events (KOBJECT_UEVENT) [Y/n/?] (NEW) y
Performance monitoring counters support (PERFCTR) [N/y/?] (NEW) y
  Init-time hardware tests (PERFCTR_INIT_TESTS) [N/y/?] (NEW) n
  Virtual performance counters support (PERFCTR_VIRTUAL) [Y/n/?] (NEW)y
kexec system call (EXPERIMENTAL) (KEXEC) [N/y/?] (NEW) n
Power Management Debug Support (PM_DEBUG) [N/y/?] (NEW) n
  Thinkpad Fn+Fx key driver (ACPI_THINKPAD) [M/n/y/?] (NEW) m
Disable ACPI for systems before Jan 1st this year (ACPI_BLACKLIST_YEAR) [0] (NEW) 0
nVidia nForce2 FSB changing (X86_CPUFREQ_NFORCE2) [N/m/y/?] (NEW) m
Packet writing on CD/DVD media (CDROM_PKTCDVD) [N/m/y/?] (NEW) ? m
  Free buffers for data gathering (CDROM_PKTCDVD_BUFFERS) [8] (NEW) 8
  Enable write caching (CDROM_PKTCDVD_WCACHE) [N/y/?] (NEW) n
        IT8212 IDE support (Experimental) (BLK_DEV_IT8212) [N/m/y/?] (NEW) y
  LSI Logic New Generation RAID Device Drivers (MEGARAID_NEWGEN) [N/y/?] (NEW) ? y
    LSI Logic Management Module (New Driver) (MEGARAID_MM) [N/m/?] (NEW) m
      LSI Logic MegaRAID Driver (New Driver) (MEGARAID_MAILBOX) [N/m/?] (NEW) m
generic Actions (NET_ACT_GACT) [N/m/y/?] (NEW) m
    generic Actions probability (GACT_PROB) [N/y/?] (NEW) ? n
    VLAN support (R8169_VLAN) [N/y/?] (NEW) ? y
Raw access to serio ports (SERIO_RAW) [N/m/y/?] (NEW) m
  Gameport data dumper (JOYSTICK_JOYDUMP) [N/m/y/?] (NEW) n
  Enable Tile Blitting Support (FB_TILEBLITTING) [N/y/?] (NEW) ? y
Filesystem caching support (CACHEFS) [N/m/y/?] (NEW) m
Kprobes (KPROBES) [N/y/?] (NEW) ? n
Include kgdb kernel debugger (KGDB) [N/y/?] (NEW) n
Enable access key retention support (KEYS) [N/y/?] (NEW) n

* Mon Sep 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc2-bk5

* Thu Sep 16 2004 Arjan van de Ven <arjanv@redhat.com>
- fix tux for x86-64 and ppc64

* Tue Sep 14 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc2
- add diskdump

* Fri Sep 10 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk17 ; make ppc32 build

* Tue Sep 07 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk13

* Mon Sep 06 2004 Arjan van de Ven <arjanv@redhat.com>
- disable online resize again
- hopefully fix Quake3 interaction with execshield
- add Alan's borken-bios-IRQ workaround patch

* Sat Sep 04 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk11

* Tue Aug 31 2004 Arjan van de Ven <arjanv@redhat.com>
- fix execshield buglet with legacy binaries
- 2.6.9-rc1-bk7

* Mon Aug 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk6

* Sat Aug 28 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk4, now with i915 DRM driver

* Sat Aug 28 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vQ3.ll
- bk4 + voluntary Q1
- and later: voluntary Q3 (Q0/Q1 were bad patches)
- disabled hugetlb (patch10), iobitmap (patch11), patch300, patch510-512, patch550,
  patch1010, patch1130
- fixed chunk in nonintconfig (patch500)
- new options:

Non-preemptible critical section timing (PREEMPT_TIMING) [N/y/?] (NEW) y
  Non-preemptible critical section tracing (LATENCY_TRACE) [N/y/?] (NEW) n
  'ondemand' cpufreq policy governor (CPU_FREQ_GOV_ONDEMAND) [N/m/y/?] (NEW) m
Low Performance USB Block driver (BLK_DEV_UB) [N/m/y/?] (NEW) m
    RAID-10 (mirrored striping) mode (EXPERIMENTAL) (MD_RAID10) [N/m/y/?] (NEW) m
  IP: tunnel transformation (INET_TUNNEL) [M/y/?] (NEW) m
    Connection tracking flow accounting (IP_NF_CT_ACCT) [N/y] (NEW) n
    SCTP protocol match support (IP_NF_MATCH_SCTP) [N/m] (NEW) m
    SCTP protocol tracking support [m/N] (NEW) n
    Use Rx and Tx Polling (NAPI) (EXPERIMENTAL) (R8169_NAPI) [N/y/?] (NEW) n
  IPMI Poweroff (IPMI_POWEROFF) [N/m/?] (NEW) m
  Intel 830M, 845G, 852GM, 855GM, 865G, 915G (DRM_I915) [N/m/y/?] (NEW) m
  I2C PCA 9564 interfaces (I2C_ALGOPCA) [N/m/?] (NEW) ? m
  PCA9564 on an ISA bus (I2C_PCA_ISA) [N/m/?] (NEW) m
  SMSC LPC47M10x and compatibles (SENSORS_SMSC47M1) [N/m/?] (NEW) m
ATI IXP 150/200/250 Modem (SND_ATIIXP_MODEM) [N/m/?] (NEW) m
Tascam US-122, US-224 and US-428 USB driver (SND_USB_USX2Y) [N/m/?] (NEW) m
  USB suspend/resume (EXPERIMENTAL) (USB_SUSPEND) [N/y/?] (NEW) n
Secure RPC: SPKM3 mechanism (EXPERIMENTAL) (RPCSEC_GSS_SPKM3) [N/m/?] (NEW) m
Collect scheduler statistics (SCHEDSTATS) [N/y/?] (NEW) y
      NSA SELinux boot parameter default value (SECURITY_SELINUX_BOOTPARAM_VALUE) [1] (NEW) 1
  Whirlpool digest algorithm (CRYPTO_WHIRLPOOL) [N/m/y/?] (NEW) m

- added fix with CONFIG_PREEMPT_VOLUNTARY definition

* Fri Aug 27 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk2 

* Wed Aug 26 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vM5.ll
- try with M5

* Tue Aug 24 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vP9.ll
- updated to voluntary preemption 9
- drm latency patch removed, it is part of voluntary 9

* Mon Aug 23 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vP7.ll
- up to voluntary P7 (previously tested P5 and P6)
- enable 4K stacks again
- enable smp build again
- add radeon low latency patch

* Mon Aug 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8.1-bk2

* Sat Aug 21 2004 Arjan van de Ven <arjanv@redhat.com>
- attempt to fix early-udev bug

* Mon Aug 16 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- added patch to sysrq command to nice all rt processes

* Sun Aug 15 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.8.1-1.520.1.vP0.ll
- moved back to 520 as a base
- updated to 2.6.8.1
- latest voluntary preemption is incompatible with some of the Fedora 
  kernel patches, so apply voluntary first and then disable
  anything that is not compatible.
- new options:
  QoS and/or fair queueing (NET_SCHED) [Y/n/?] y
    Packet scheduler clock source = 1
  enabled kernel preemption
  enabled realcap lsm module
  enabled soundcore
  enabled ntfs read support
- added patch for main Makefile, the kernel version in version.h is not
  properly calculated because of the extra release number (8.1)
 
* Fri Aug 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc4-bk3
- split execshield up some more

* Fri Aug 13 2004 Dave Jones <davej@redhat.com>
- Update SCSI whitelist again with some more card readers.

* Thu Aug 12 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.7-0.1.rc4O7.ll
- updated to voluntary preemption rc4-O7 (now includes preempt-timing)
- new options:
  Non-preemptible critical section tracing (LATENCY_TRACE) [N/y/?] (NEW) y
This option enables a kernel tracing mechanism that will track
precise kernel execution during critical sections. Note that
kernel size and overhead increases noticeably with this option.
- disable DAZ hack, would not really be the way to do it anyway, 
  apparently some steppings of old p4 version do not have the
  DAZ bit. Probably a job for some userland utility. 

- keep 4K stacks disabled
- disable LATENCY_TRACE option (new)
 
* Tue Aug 10 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.7-1.rc4.ll
- updated to rc4, voluntary preempt rc3-O5, added preempt timing patch
- enabled "denormals are zero" in the fpu (tested: patch does nothing...)
- disable 4KSTACKS temporarily for testing
- disable smp build temporarily

* Mon Aug  9 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.7-1.rc3.ll
- updated to rc3 and voluntary preemption O4
- options:
    Suspend-to-Disk Support (PM_DISK) [N/y/?] (NEW) n
Build Adapter Firmware with Kernel Build (AIC7XXX_BUILD_FIRMWARE) [N/y/?] (NEW) n
Build Adapter Firmware with Kernel Build (AIC79XX_BUILD_FIRMWARE) [N/y/?] (NEW) n
IBM Power Linux RAID adapter support (SCSI_IPR) [N/m/?] (NEW) m
enable driver internal trace (SCSI_IPR_TRACE) [N/y/?] (NEW) n
enable adapter dump support (SCSI_IPR_DUMP) [N/y/?] (NEW) n
Gameport data dumper (INPUT_JOYDUMP) [N/m/y/?] (NEW) n

* Mon Aug 9 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc3-bk3

* Thu Aug  5 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.7-1.rc2_mm2.ll
- moved from Arjan bitkeeper patches to rc2-mm2 to be able to 
  apply the latest Ingo Molnar patches for voluntary preemption
  (and have them be proc configurable). All non-compatible patches
  have been commented out, some do not apply, some are already 
  included in the mm2 patch. The configuration files are based on
  the ones that ship with Arjan's 503 build. 
- fix parallel port irq enable and disable in cpia_pp.c and plip.c
- turn on NTFS support (read only)
- turn off kernel module signing
- for more details about the patches see: 
  http://kerneltrap.org/node/view/3573
  http://people.redhat.com/mingo/voluntary-preempt/
  ftp://ftp.kernel.org/pub/linux/kernel/people/akpm/patches/2.6/2.6.8-rc2/2.6.8-rc2-mm2/

* Wed Aug 4 2004 Arjan van de Ven <arjanv@redhat.com>
- Add the flex-mmap bits for s390/s390x (Pete Zaitcev)
- Add flex-mmap for x86-64 32 bit emulation
- 2.6.8-rc3

* Mon Aug 2 2004 Arjan van de Ven <arjanv@redhat.com>
- Add Rik's token trashing control patch

* Sun Aug 1 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk11

* Fri Jul 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk8

* Wed Jul 28 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk6
- make a start at splitting up the execshield patchkit

* Fri Jul 16 2004 Arjan van de Ven <arjanv@redhat.com>
- ppc32 embedded updates

* Thu Jul 15 2004 Arjan van de Ven <arjanv@redhat.com>
- make USB modules again and add Alan's real fix for the SMM-meets-USB bug
- 2.6.8-rc1-bk4

* Wed Jul 14 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc1-bk3

* Tue Jul 13 2004 Arjan van de Ven <arjanv@redhat.com>
- add "enforcemodulesig" boot option to make the kernel load signed modules only

* Mon Jul 12 2004 Arjan van de Ven <arjanv@redhat.com>
- updated voluntary preempt
- 2.6.8-rc1

* Wed Jul 7 2004 Arjan van de Ven <arjanv@redhat.com>
- fix boot breakage that was hitting lots of people (Dave Jones)

* Tue Jul 6 2004 Arjan van de Ven <arjanv@redhat.com>
- add voluntary preemption patch from Ingo
- 2.6.7-bk19

* Tue Jun 29 2004 Arjan van de Ven <arjanv@redhat.com>
- make a start at gpg signed modules support

* Sat Jun 27 2004 Arjan van de Ven <arjanv@redhat.com>
- experiment with making the hardlink call in post more efficient
- 2.6.7-bk9

* Thu Jun 24 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk7
- Add wli's patch to allocate memory bottom up not top down
- change some config options in the kernel-sourcecode package that are
  good for rpm kernel builds but not for custom user builds to more appropriate 
  default values.
- reenable kernel-sourcecode again for a few builds 

* Wed Jun 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk5
- fix tux unresolved symbols (#126532)

* Mon Jun 21 2004 Arjan van de Ven <arjanv@redhat.com>
- make kernel-doc and kernel-sourcecode builds independent of eachother
- disable kernel-sourcecode builds entirely, we'll be replacing it with documentation
  on how to use the src.rpm instead for building your own kernel.

* Sat Jun 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk2

* Thu Jun 17 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.7-1.437.1
- sync with 2.6.7-1.437
- updated Con Kolivas patches, apply staircase scheduler

* Tue Jun 15 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.434.1
- updated staircase scheduler

* Sun Jun 13 2004 Arjan van de Ven <arjanv@redhat.com>
- add patch from DaveM to fix the ppp-keeps-iface-busy bug

* Sat Jun 12 2004 Arjan van de Ven <arjanv@redhat.com>
- add fix from Andi Kleen/Linus for the fpu-DoS

* Thu Jun 10 2004 Arjan van de Ven <arjanv@redhat.com>
- disable mlock-uses-rlimit patch, it has a security hole and needs more thought
- revert airo driver to the FC2 one since the new one breaks

* Wed Jun  9 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.424.2
- added staircase scheduler (http://ck.kolivas.org/patches/2.6/2.6.7-rc3/)

* Wed Jun  9 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.424.1
- preempt, soundcore, drm latency

* Tue Jun 8 2004 Dave Jones <davej@redhat.com>
- Update to 2.6.7rc3

* Fri Jun 4 2004 Arjan van de Ven <arjanv@redhat.com>
- fix the mlock-uses-rlimit patch

* Wed Jun 2 2004 David Woodhouse <dwmw2@redhat.com>
- Add ppc64 (Mac G5)

* Wed Jun 2 2004 Arjan van de Ven <arjanv@redhat.com>
- add a forward port of the mlock-uses-rlimit patch
- add NX support for x86 (Intel, Ingo)

* Tue Jun 1 2004 Arjan van de Ven <arjanv@redhat.com>
- refresh ext3 reservation patch

* Tue Jun  1 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.393.4.ll
- yet another with drm and preempt

* Tue Jun  1 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.393.3.ll
- another rebuild with the lowlat patches for drm and preempt off

* Sun May 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-rc2
- set the ACPI OS name to "Microsoft Windows XP" for better compatibility

* Fri May 28 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.393.2.ll
- another rebuild with preempt off

* Thu May 27 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.393.1.ll
- resync with Ajanv's 1.391

* Thu May 27 2004 Pete Zaitcev <zaitcev@redhat.com>
- Fix qeth and zfcp (s390 drivers): align qib by 256, embedded into qdio_irq.

* Thu May 27 2004 Dave Jones <davej@redhat.com>
- Fix the crashes on boot on Asus P4P800 boards. (#121819)

* Wed May 26 2004 Dave Jones <davej@redhat.com>
- Lots more updates to the SCSI whitelist for various
  USB card readers. (#112778, among others..)

* Wed May 26 2004 Arjan van de Ven <arjanv@redhat.com>
- back out ehci suspend/resume patch, it breaks
- add fix for 3c59x-meets-kudzu bug from Alan

* Tue May 25 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.6.6-1.383.1.ll
- add preempt, soundcore, rt module to configs (based on 1.379)

* Tue May 25 2004 Arjan van de Ven <arjanv@redhat.com>
- try improving suspend/resume by restoring more PCI state
- 2.6.7-rc1-bk1

* Mon May 24 2004 Dave Jones <davej@redhat.com>
- Add yet another multi-card reader to the whitelist (#85851)

* Sun May 23 2004 Dave Jones <davej@redhat.com>
- Add another multi-card reader to the whitelist (#124048)

* Wed May 19 2004 Arjan van de Ven <arjanv@redhat.com>
- put firewire race fix in (datacorruptor)

* Tue May 18 2004 Dave Jones <davej@redhat.com>
- Fix typo in ibmtr driver preventing compile (#123391)

* Mon May 17 2004 Arjan van de Ven <arjanv@redhat.com>
- update to 2.6.6-bk3
- made kernel-source and kernel-doc noarch.rpm's since they are not
  architecture specific.

* Sat May 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix non-booting on Transmeta cpus (Peter Anvin)
- fix count leak in message queues

* Fri May 07 2004 Arjan van de Ven <arjanv@redhat.com>
- more ide cache flush work
- patch from scsi-bk to fix sd refcounting

* Thu May 06 2004 Arjan van de Ven <arjanv@redhat.com>
- some more ide cache flush fixes 

* Wed May 05 2004 Arjan van de Ven <arjanv@redhat.com>
- fix bug 122504
- convert b44 to ethtool ops (jgarzik)
- make IDE do a cache-flush on shutdown (me/Alan)

* Tue May 04 2004 Arjan van de Ven <arjanv@redhat.com>
- work around i810/i830 DRM issue

* Fri Apr 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc3-bk1
- make amd64 boot again
- fix vm86-vs-4g4g interaction (Ingo)

* Thu Apr 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc2
 
* Tue Apr 20 2004 Arjan van de Ven <arjanv@redhat.com>
- add the ext3 online resize patch

* Mon Apr 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc1-bk3
- add the objrmap vm from the -mm tree; it needs testing

* Thu Apr 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-bk2
- disable DISCONTIGMEM on ia64 for performance
- fix sleep_on use in reiserfs (Chris Mason)

* Tue Apr 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc4
- reenable sg driver for scsi tape changers and such
- the sk98lin driver oopses on module unload, preven that

* Mon Apr 12 2004 Arjan van de Ven <arjanv@redhat.com>
- fix "bad pmd" bug with patch from Ingo

* Fri Apr 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc3
- finish up the -mc2 merge
- latest 4g/4g patch from Ingo
- latest execshield patch from Ingo
- fix a few framebuffer bugs

* Thu Apr 08 2004 Arjan van de Ven <arjanv@redhat.com>
- first attempt at a 2.6.5-mc2 merge

* Thu Apr 08 2004 Dave Jones <davej@redhat.com>
- Add in missing SiS AGP fix.

* Tue Apr 06 2004 Dave Jones <davej@redhat.com>
- More agpgart fixes.

* Fri Apr 02 2004 Arjan van de Ven <arjanv@redhat.com>
- fix another 4g/4g-vs-resume bug

* Tue Mar 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc3
- fix PCI posting bug in i830 DRM

* Mon Mar 29 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk8

* Mon Mar 29 2004 Dave Jones <davej@redhat.com>
- Include latest agpgart fixes.

* Thu Mar 25 2004 Arjan van de Ven <arjanv@redhat.com>
- more DRM fixes
- add the fsync patches from akpm

* Tue Mar 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk3
- fix direct userspace memory access in i830 drm driver

* Mon Mar 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk2
- some stackbloat reductions from Dave and me

* Sat Mar 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2

* Tue Mar 16 2004 Dave Jones <davej@redhat.com>
- 2.6.5-rc1

* Mon Mar 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk3
- fix oops in toshiba_acpi (Barry K. Nathan)

* Sat Mar 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk2 merge 

* Thu Mar 11 2004 Arjan van de Ven <arjanv@redhat.com>
- renable sonypi driver that was off accidentally
- 2.6.4-final 
- fix the oops on alsa module unloads

* Wed Mar 10 2004 Arjan van de Ven <arjanv@redhat.com>
- add ppc64/iseries, ppc32 (powermac/ibook) and ia64 architectures
- 2.6.4-rc3 

* Tue Mar 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-rc2-bk5
- fix nfs-vs-selinux issue
- fix typo in URL as per #117849

* Mon Mar 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix race in lp.c (#117710)
- 2.6.4-rc2-bk3
- attempt to fix S3 suspend-to-ram with 4g/4g split

* Sat Mar 06 2004 Arjan van de Ven <arjanv@redhat.com>
- fix reiserfs
- set HZ to 1000 again for some tests

* Wed Feb 25 2004 Arjan van de Ven <arjanv@redhat.com>
- merge back a bunch of fedora fixes
- disable audit

* Tue Feb 24 2004 Arjan van de Ven <arjanv@redhat.com>
- audit bugfixes
- update tux to a working version
- 2.6.3-bk5 merge

* Fri Feb 20 2004 Arjan van de Ven <arjanv@redhat.com>
- re-add and enable the Auditing patch
- switch several cpufreq modules to built in since detecting in userspace
  which to use is unpleasant
* Thu Jul 03 2003 Arjan van de Ven <arjanv@redhat.com>
- 2.6 start

